@@ -5,7 +5,7 @@
 #' are utilized as base-learners in the case of functional responses. 
 #' Scalar responses are treated as the special case where each functional response has 
 #' only one observation. 
-#' This function is a wrapper for \code{mboost}'s \code{\link{mboost}} and its 
+#' This function is a wrapper for \code{mboost}'s \code{\link[mboost]{mboost}} and its 
 #' siblings to fit models of the general form 
 #' \deqn{\xi(Y_i(t) | X_i = x_i) = \sum_{j} h_j(x_i, t), i = 1, ..., N,} 
 #' with a functional (but not necessarily continuous) response \eqn{Y(t)}, 
@@ -52,7 +52,7 @@
 #' @param check0 logical, for response in matrix form, i.e. response that is observed on a common grid, 
 #' check the fitted effects for the sum-to-zero constraint 
 #' \eqn{h_j(x_i)(t) = 0} for all \eqn{t} and give a warning if it is not fulfilled. Defaults to \code{FALSE}. 
-#' @param ... additional arguments passed to \code{\link{mboost}}, 
+#' @param ... additional arguments passed to \code{\link[mboost]{mboost}}, 
 #' including, \code{family} and \code{control}.
 #' 
 #' @details In matrix representation of functional response and covariates each row 
@@ -63,7 +63,7 @@
 #' 
 #' If it is possible to represent the model as a generalized linear array model 
 #' (Currie et al., 2006), the array structure is used for an efficient implementation, 
-#' see \code{\link{mboost}}. This is only possible if the design 
+#' see \code{\link[mboost]{mboost}}. This is only possible if the design 
 #' matrix can be written as the Kronecker product of two marginal design 
 #' matrices yielding a functional linear array model (FLAM), 
 #' see Brockhaus et al. (2015) for details. 
@@ -93,12 +93,12 @@
 #' time-direction, use \code{timeformula = ~bols(1)}. In this case, a penalty in the 
 #' time-direction is used, see Brockhaus et al. (2015) for details.  
 #' Alternatively, the scalar response is fitted as scalar response, like in the function
-#' \code{\link{mboost}} in package mboost. 
+#' \code{\link[mboost]{mboost}} in package mboost. 
 #' The advantage of using \code{FDboost} in that case 
 #' is that methods for the functional base-learners are available, e.g., \code{plot}. 
 #' 
 #' The desired regression type is specified by the \code{family}-argument, 
-#' see the help-page of \code{\link{mboost}}. For example a mean regression model is obtained by  
+#' see the help-page of \code{\link[mboost]{mboost}}. For example a mean regression model is obtained by  
 #' \code{family = Gaussian()} which is the default or median regression 
 #' by \code{family = QuantReg()}; 
 #' see \code{\link[mboost]{Family}} for a list of implemented families. 
@@ -176,7 +176,7 @@
 #' @return An object of class \code{FDboost} that inherits from \code{mboost}.
 #' Special \code{\link{predict.FDboost}}, \code{\link{coef.FDboost}} and 
 #' \code{\link{plot.FDboost}} methods are available. 
-#' The methods of \code{\link{mboost}} are available as well, 
+#' The methods of \code{\link[mboost]{mboost}} are available as well, 
 #' e.g., \code{\link[mboost:methods]{extract}}. 
 #' The \code{FDboost}-object is a named list containing: 
 #' \item{...}{all elements of an \code{mboost}-object}
@@ -198,7 +198,7 @@
 #' 
 #' @author Sarah Brockhaus, Torsten Hothorn
 #' 
-#' @seealso Note that \link{FDboost} calls \code{\link{mboost}} directly.  
+#' @seealso Note that \link{FDboost} calls \code{\link[mboost]{mboost}} directly.  
 #' See, e.g., \code{\link[FDboost]{bsignal}} and \code{\link[FDboost]{bbsc}} 
 #' for possible base-learners. 
 #' 
@@ -456,17 +456,17 @@ FDboost <- function(formula,          ### response ~ xvars
   ### save formula of FDboost before it is changed
   formulaFDboost <- formula
   
-  tf <- terms.formula(formula, specials = c("c"))
+  tf <- terms.formula(formula, specials = "c")
   trmstrings <- attr(tf, "term.labels")
   equalBrackets <- NULL
   if(length(trmstrings) > 0){
     ## insert id at end of each base-learner
-    trmstrings2 <- paste(substr(trmstrings, 1 , nchar(trmstrings)-1), ", index=", id[2],")", sep = "")
+    trmstrings2 <- paste0(substr(trmstrings, 1 , nchar(trmstrings)-1), ", index=", id[2],")")
     ## check if number of opening brackets is equal to number of closing brackets
-    equalBrackets <- sapply(1:length(trmstrings2), function(i)
+    equalBrackets <- sapply(seq_along(trmstrings2), function(i)
     {
-      sapply(regmatches(trmstrings2[i], gregexpr("\\(", trmstrings2[i])), length) ==
-        sapply(regmatches(trmstrings2[i], gregexpr("\\)", trmstrings2[i])), length)
+      lengths(regmatches(trmstrings2[i], gregexpr("(", trmstrings2[i], fixed = TRUE))) ==
+        lengths(regmatches(trmstrings2[i], gregexpr(")", trmstrings2[i], fixed = TRUE)))
     })
   }
   
@@ -474,36 +474,36 @@ FDboost <- function(formula,          ### response ~ xvars
   if(inherits(try(id), "try-error")) stop("id must either be NULL or a formula object.")
   if(missing(timeformula) || inherits(try(timeformula),  "try-error")) 
     stop("timeformula must either be NULL or a formula object.")
-    stopifnot(class(formula) == "formula")
-  if(!is.null(timeformula)) stopifnot(class(timeformula) == "formula")
+    stopifnot(inherits(formula, "formula"))
+  if(!is.null(timeformula)) stopifnot(inherits(timeformula, "formula"))
   
   ## insert the id variable into the formula, to treat it like the other variables
   if(!is.null(id)){
-    stopifnot(class(id) == "formula")
+    stopifnot(inherits(id, "formula"))
     ##tf <- terms.formula(formula, specials = c("c"))
     ##trmstrings <- attr(tf, "term.labels")
     ##equalBrackets <- NULL
     if(length(trmstrings) > 0){
       ## insert index into the other base-learners of the tensor-product as well
-      for(i in 1:length(trmstrings)){
-        if(grepl( "%X", trmstrings2[i])){
-          temp <- unlist(strsplit(trmstrings2[i], "%X"))
+      for(i in seq_along(trmstrings)){
+        if(grepl( "%X", trmstrings2[i], fixed = TRUE)){
+          temp <- unlist(strsplit(trmstrings2[i], "%X", fixed = TRUE))
           temp1 <- temp[-length(temp)]
           ## http://stackoverflow.com/questions/2261079
           ## delete all trailing whitespace
           trim.trailing <- function (x) sub("\\s+$", "", x) 
           temp1 <- trim.trailing(temp1)
-          temp1 <- paste(substr(temp1, 1 , nchar(temp1)-1), ", index=", id[2],")", sep = "")
+          temp1 <- paste0(substr(temp1, 1 , nchar(temp1)-1), ", index=", id[2],")")
           trmstrings2[i] <- paste0(paste0(temp1, collapse = " %X"), " %X", temp[length(temp)]) 
         } 
         ## do not add index to base-learners bhistx()
-        if( grepl("bhistx", trmstrings[i]) ) trmstrings2[i] <- trmstrings[i] 
+        if( grepl("bhistx", trmstrings[i], fixed = TRUE) ) trmstrings2[i] <- trmstrings[i] 
         ##  do not add an index if an index is already part of the formula
         if( grepl("index[[:blank:]]*=", trmstrings[i]) ) trmstrings2[i] <- trmstrings[i]
         ##  do not add an index if an index for %A%, %A0%, %O%
-        if( grepl("%A%", trmstrings[i]) ) trmstrings2[i] <- trmstrings[i]
-        if( grepl("%A0%", trmstrings[i]) ) trmstrings2[i] <- trmstrings[i]
-        if( grepl("%O%", trmstrings[i]) ) trmstrings2[i] <- trmstrings[i]
+        if( grepl("%A%", trmstrings[i], fixed = TRUE) ) trmstrings2[i] <- trmstrings[i]
+        if( grepl("%A0%", trmstrings[i], fixed = TRUE) ) trmstrings2[i] <- trmstrings[i]
+        if( grepl("%O%", trmstrings[i], fixed = TRUE) ) trmstrings2[i] <- trmstrings[i]
         ##  do not add an index for base-learner that do not have brackets
         if( i %in% which(!equalBrackets) ) trmstrings2[i] <- trmstrings[i]
       }
@@ -538,7 +538,7 @@ FDboost <- function(formula,          ### response ~ xvars
     scalarResponse <- TRUE
     if(is.null(timeformula)) scalarNoFLAM <- TRUE
     
-    if(grepl("df", formula[3]) | !grepl("lambda", formula[3]) ){
+    if(grepl("df", formula[3], fixed = TRUE) || !grepl("lambda", formula[3], fixed = TRUE) ){
       timeformula <- ~bols(ONEtime, intercept = FALSE, df = 1)
     }else{
       timeformula <- ~bols(ONEtime, intercept = FALSE)
@@ -555,7 +555,7 @@ FDboost <- function(formula,          ### response ~ xvars
 
   }
   
-  if(scalarResponse & !identical(numInt,"equal")) 
+  if(scalarResponse && !identical(numInt,"equal")) 
     stop("Integration weights numInt must be set to 'equal' for scalar response.")
   
   ## extract time(s) from timeformula 
@@ -582,7 +582,7 @@ FDboost <- function(formula,          ### response ~ xvars
   allCovs <- unique(c(nameid, all.vars(formula)))
   if(length(allCovs) > 1){
     data <- data[allCovs[!allCovs %in% c(yname, nameyind)] ]
-    if( any(is.na(names(data))) ) data <- data[ !is.na(names(data)) ]
+    if( anyNA(names(data)) ) data <- data[ !is.na(names(data)) ]
   }else{
     data <- list(NULL)  # <SB> intercept-model without covariates
   } 
@@ -621,7 +621,7 @@ FDboost <- function(formula,          ### response ~ xvars
       nr <- nrow(response)
       if(!is.list(time))
         stopifnot(ncol(response) == length(time)) else
-          stopifnot(all(ncol(response) == sapply(time[sapply(time, is.vector)], length)))
+          stopifnot(all(ncol(response) == lengths(time[sapply(time, is.vector)])))
       nc <- ncol(response)
       dresponse <- as.vector(response) # column-wise stacking of response 
       ## convert characters to factor 
@@ -633,11 +633,11 @@ FDboost <- function(formula,          ### response ~ xvars
       stopifnot(is.null(dim(response))) ## stopifnot(is.vector(response))
       # check length of response and its time and index
       if(is.list(time))
-        stopifnot(all(length(response) == sapply(time, length)) & length(response) == length(id)) else
+        stopifnot(all(length(response) == lengths(time)) & length(response) == length(id)) else
           stopifnot(length(response) == length(time) & length(response) == length(id))
       
-      if(any(is.na(response))) warning("For non-grid observations the response should not contain missing values.")
-      if( !all(sort(unique(id)) == 1:length(unique(id))) ) stop("id has to be integers 1, 2, 3,..., N.")
+      if(anyNA(response)) warning("For non-grid observations the response should not contain missing values.")
+      if( !all(sort(unique(id)) == seq_along(unique(id))) ) stop("id has to be integers 1, 2, 3,..., N.")
       
       nr <- length(response) # total number of observations
       nc <- length(unique(id)) # number of trajectories
@@ -671,23 +671,23 @@ FDboost <- function(formula,          ### response ~ xvars
 
   ## get formula over time
   tfm <- paste(deparse(timeformula), collapse = "")
-  tfm <- strsplit(tfm, "~")[[1]]
-  tfm <- strsplit(tfm[2], "\\+")[[1]]
+  tfm <- strsplit(tfm, "~", fixed = TRUE)[[1]]
+  tfm <- strsplit(tfm[2], "+", fixed = TRUE)[[1]]
   
   ## get formula in covariates 
   cfm <- paste(deparse(formula), collapse = "") 
-  cfm <- strsplit(cfm, "~")[[1]]
+  cfm <- strsplit(cfm, "~", fixed = TRUE)[[1]]
   cfm0 <- cfm
   #xfm <- strsplit(cfm[2], "\\+")[[1]]
   xfm <- trmstrings
   
   ## check that the timevariable in timeformula and in the bhistx-base-learners have the same name
-  if(any(grepl("bhistx", trmstrings))){
-    for(j in 1:length(trmstrings)){
-      if(any(grepl("bhistx", trmstrings[j]))){
-        if(grepl("%X", trmstrings[j]) ){
+  if(any(grepl("bhistx", trmstrings, fixed = TRUE))){
+    for(j in seq_along(trmstrings)){
+      if(any(grepl("bhistx", trmstrings[j], fixed = TRUE))){
+        if(grepl("%X", trmstrings[j], fixed = TRUE) ){
           temp <- strsplit(trmstrings[[j]], "%X.*%")[[1]]
-          temp <- temp[ grepl("bhistx", temp) ]
+          temp <- temp[ grepl("bhistx", temp, fixed = TRUE) ]
           ## pryr::standardise_call(quote(bhistx(X1h, df=3))) 
           temp_name <- all.vars(formula(paste("~", temp)))[1]
         }else{
@@ -707,17 +707,17 @@ FDboost <- function(formula,          ### response ~ xvars
     }
   }
     
-  yfm <- strsplit(cfm[1], "\\+")[[1]] ## name of response 
+  yfm <- strsplit(cfm[1], "+", fixed = TRUE)[[1]] ## name of response 
   
   ## set up formula for effects constant in time
   if(length(where.c) > 0){
     # set c_df to the df/lambda in timeformula
-    if( grepl("lambda", tfm) || 
-          ( grepl("bols", tfm) &  !grepl("df", tfm)) ){
-      c_lambda <- eval(parse(text = paste(tfm, "$dpp(rep(1.0,", length(time), "))$df()", sep = "")))["lambda"]
+    if( grepl("lambda", tfm, fixed = TRUE) || 
+          ( grepl("bols", tfm, fixed = TRUE) &&  !grepl("df", tfm, fixed = TRUE)) ){
+      c_lambda <- eval(parse(text = paste0(tfm, "$dpp(rep(1.0,", length(time), "))$df()")))["lambda"]
       cfm <- paste("bols(ONEtime, intercept = FALSE, lambda = ", c_lambda ,")")
     } else{
-      c_df <- eval(parse(text=paste(tfm, "$dpp(rep(1.0,", length(time), "))$df()", sep = "")))["df"]
+      c_df <- eval(parse(text=paste0(tfm, "$dpp(rep(1.0,", length(time), "))$df()")))["df"]
       cfm <- paste("bols(ONEtime, intercept = FALSE, df = ", c_df ,")")
     }
   }
@@ -737,28 +737,28 @@ FDboost <- function(formula,          ### response ~ xvars
     } else{
       which_equalBrackets <- which(equalBrackets)
     }
-    xfmTemp <- paste(substr(xfm[which_equalBrackets], 1 , 
-                        nchar(xfm[which_equalBrackets]) - 1 ), ")", sep = "") # , index=id is done in the beginning
+    xfmTemp <- paste0(substr(xfm[which_equalBrackets], 1 , 
+                        nchar(xfm[which_equalBrackets]) - 1 ), ")") # , index=id is done in the beginning
     xfm[which_equalBrackets] <- xfmTemp
     rm(xfmTemp)
     tmp <- outer(xfm, tfm, function(x, y) paste(x, y, sep = "%X%"))
   }
 
   # do not expand an effect bconcurrent() or bhist() with timeformula
-  if( length(c(grep("bconcurrent", tmp), grep("bhis", tmp)) ) > 0 ) 
-    tmp[c(grep("bconcurrent", tmp), grep("bhist", tmp))] <- xfm[c(grep("bconcurrent", tmp), grep("bhist", tmp))]  
+  if (any(grepl("bconcurrent|bhis", tmp)))
+    tmp[c(grep("bconcurrent", tmp, fixed = TRUE), grep("bhist", tmp, fixed = TRUE))] <- xfm[c(grep("bconcurrent", tmp, fixed = TRUE), grep("bhist", tmp, fixed = TRUE))]  
   
   ## do not expand effects in formula including %A% with timeformula
-  if( length(grep("%A%", xfm)) > 0 ) 
-    tmp[grep("%A%", xfm)] <- xfm[grep("%A%", xfm)]
+  if( any(grepl("%A%", xfm, fixed = TRUE)) ) 
+    tmp[grep("%A%", xfm, fixed = TRUE)] <- xfm[grep("%A%", xfm, fixed = TRUE)]
   
   ## do not expand effects in formula including %A0% with timeformula
-  if( length(grep("%A0%", xfm)) > 0 ) 
-    tmp[grep("%A0%", xfm)] <- xfm[grep("%A0%", xfm)]
+  if( any(grepl("%A0%", xfm, fixed = TRUE)) ) 
+    tmp[grep("%A0%", xfm, fixed = TRUE)] <- xfm[grep("%A0%", xfm, fixed = TRUE)]
   
   ## do not expand effects in formula including %O% with timeformula
-  if( length(grep("%O%", xfm)) > 0 ) 
-    tmp[grep("%O%", xfm)] <- xfm[grep("%O%", xfm)]
+  if( any(grepl("%O%", xfm, fixed = TRUE)) ) 
+    tmp[grep("%O%", xfm, fixed = TRUE)] <- xfm[grep("%O%", xfm, fixed = TRUE)]
   
   ## expand with a constant effect in t-direction 
   if(length(where.c) > 0){
@@ -781,7 +781,7 @@ FDboost <- function(formula,          ### response ~ xvars
     get_df <- function(bl){
       split_bl <- unlist(strsplit(bl, split = "%.{1,3}%"))
       all_df <- c()
-      for(i in 1:length(split_bl)){
+      for(i in seq_along(split_bl)){
         parti <- parse(text = split_bl[i])[[1]] 
         parti <- expand.call(definition = get(as.character(parti[[1]])), call = parti)
         dfi <- parti$df # df of part i in bl 
@@ -833,11 +833,11 @@ FDboost <- function(formula,          ### response ~ xvars
 
   ### replace "1" with intercept base learner
   formula_intercept <- FALSE
-  if ( any( gsub(" ", "", strsplit(cfm0[2], "\\+")[[1]]) ==  "1")){
+  if ( any( gsub(" ", "", strsplit(cfm0[2], "+", fixed = TRUE)[[1]], fixed = TRUE) ==  "1")){
     formula_intercept <- TRUE
     ## use df or lambda as in timeformula 
-    if( any(grepl("lambda", deparse(timeformula))) || 
-        any(( grepl("bols", deparse(timeformula)) &  !grepl("df", deparse(timeformula)))) ){
+    if( any(grepl("lambda", deparse(timeformula), fixed = TRUE)) || 
+        any(( grepl("bols", deparse(timeformula), fixed = TRUE) &  !grepl("df", deparse(timeformula), fixed = TRUE))) ){
       tmp <- c("bols(ONEx, intercept = FALSE, lambda = 0)", tmp)
     } else{
       tmp <- c("bols(ONEx, intercept = FALSE, df = 1)", tmp)
@@ -879,9 +879,9 @@ FDboost <- function(formula,          ### response ~ xvars
       ## get the limits argument
       current_bl <- attr(terms_fm_bhist, "variables")[[places_bhist[pl] + 1]]
       # for base-learner with interaction, find bhistx / bhist
-      if(any(grepl("%X", current_bl))){ 
+      if(any(grepl("%X", current_bl, fixed = TRUE))){ 
         #current_bl <- current_bl[ grepl("bhist", current_bl) ]
-        arg_limits <- eval(as.call(as.list(current_bl[grepl("bhist", current_bl)])[[1]])$limits) 
+        arg_limits <- eval(as.call(as.list(current_bl[grepl("bhist", current_bl, fixed = TRUE)])[[1]])$limits) 
       }else{
         # limits argument of bhist / bhistx 
         arg_limits <- eval(as.call(current_bl)$limits)
@@ -944,7 +944,7 @@ FDboost <- function(formula,          ### response ~ xvars
   ### multiply integration weights numInt to weights and w
   if(is.numeric(numInt)){
     .numInt_len_check <- if(is.list(time))
-      all(length(numInt) == sapply(time, length))  else 
+      all(length(numInt) == lengths(time))  else 
         length(numInt) == length(time)
     if(!.numInt_len_check) 
       stop("Length of integration weights and time vector are not equal.")
@@ -973,7 +973,7 @@ FDboost <- function(formula,          ### response ~ xvars
   ### -> use one scalar/user-specified offset like in mboost
   
   ### in case of factor or multiple time variables set offset to 0 and give a warning
-  if(is.list(time) | !is.numeric(time)) {
+  if(is.list(time) || !is.numeric(time)) {
     .offsetwarning <- is.null(offset)
     if(!.offsetwarning) {
       .offsetwarning <- (offset == "scalar")
@@ -1045,7 +1045,7 @@ FDboost <- function(formula,          ### response ~ xvars
         }
         # meanY <- sapply(1:nc, function(i) offsetFun(responseInter[,i], 1*!is.na(responseInter[,i])))
         
-        if( is.null(meanY) ||  any(is.na(meanY)) ){
+        if( is.null(meanY) || anyNA(meanY) ){
           warning("Mean offset cannot be computed by family@offset(). Use a weighted mean instead.")
           meanY <- c()
           for(i in 1:nc){
@@ -1081,7 +1081,7 @@ FDboost <- function(formula,          ### response ~ xvars
         offset <- as.vector(matrix(offsetVec, ncol = ncol(response), nrow = nrow(response), byrow = TRUE))    
       }else{ 
         ### scalar response or mean-centered response -> one constant offset value is used
-        if(dim(response)[2] == 1 |  all(colMeans(response, na.rm = TRUE) < .Machine$double.eps *10^10)){ 
+        if(dim(response)[2] == 1 || all(colMeans(response, na.rm = TRUE) < .Machine$double.eps *10^10)){ 
           offsetVec <- offset
           predictOffset <- offset 
         }else{ 
@@ -1163,10 +1163,10 @@ FDboost <- function(formula,          ### response ~ xvars
   if(check0 && length(ret$baselearner) > 1 && is.null(id) && dim(response)[2] != 1){
     
     # do not check the smooth intercept
-    if(any( gsub(" ", "", strsplit(cfm[2], "\\+")[[1]]) ==  "1")){
+    if(any( gsub(" ", "", strsplit(cfm[2], "+", fixed = TRUE)[[1]], fixed = TRUE) ==  "1")){
       effectsToCheck <- 2:length(ret$baselearner)
     }else{
-      effectsToCheck <- 1:length(ret$baselearner)
+      effectsToCheck <- seq_along(ret$baselearner)
     }
     # predict each effect separately
     pred <- predict(ret, which = effectsToCheck)
@@ -1188,7 +1188,7 @@ FDboost <- function(formula,          ### response ~ xvars
   ## generate an id-variable for a regular response
   if(is.null(id)){
     if(scalarResponse){
-      id <- 1:NROW(response)
+      id <- seq_len(NROW(response))
     }else{
       id <- rep(1:ydim[1], times = ydim[2])
     }
