@@ -47,7 +47,7 @@
 #' 
 #' @note Note that parallelization can be achieved by defining
 #' the \code{resampling_fun_outer} or \code{_inner} accordingly.
-#' See, e.g., \code{\link{cvrisk}} on how to parallelize resampling
+#' See, e.g., \code{\link[mboost]{cvrisk}} on how to parallelize resampling
 #' functions or the examples below. Also note that by defining
 #' a custum inner or outer resampling function the respective
 #' argument \code{B_inner} or \code{B_outer} is ignored.
@@ -186,7 +186,7 @@ bootstrapCI <- function(object, which = NULL,
   type_inner <- match.arg(type_inner)
   
   ########## check for scalar response #########
-  scalarResp <- "FDboostScalar" %in% class(object)
+  scalarResp <- inherits(object, "FDboostScalar")
 
   ########## define outer resampling function if NULL #########
   if(is.null(resampling_fun_outer)){
@@ -227,7 +227,7 @@ bootstrapCI <- function(object, which = NULL,
   }
     
   # 'catch' error caused by using the cvrisk function for inner and outer resampling
-  if(identical(resampling_fun_outer, cvrisk) & 
+  if(identical(resampling_fun_outer, cvrisk) && 
      identical(resampling_fun_inner, cvrisk)) 
     stop("Please specify a different outer resampling function.")
   
@@ -251,7 +251,7 @@ bootstrapCI <- function(object, which = NULL,
   
   ########## format coefficients #########
   # number of baselearners
-  nrEffects <- max(sapply(1:length(coefs), 
+  nrEffects <- max(sapply(seq_along(coefs),
                           function(i) length(coefs[[i]]$smterms)))
   
   isFacSpecEffect <- sapply(1:nrEffects, 
@@ -272,10 +272,10 @@ bootstrapCI <- function(object, which = NULL,
   { 
     if(isFacSpecEffect[i]){
       # factor specific effect
-      lapply(1:length(coefs), function(j) lapply(1:(coefs[[1]]$smterms[[i]]$numberLevels), 
+      lapply(seq_along(coefs), function(j) lapply(1:(coefs[[1]]$smterms[[i]]$numberLevels),
                                                  function(k) coefs[[j]]$smterms[[i]][[k]]$value))
     }else{
-      lapply(1:length(coefs), function(j) coefs[[j]]$smterms[[i]]$value)
+      lapply(seq_along(coefs), function(j) coefs[[j]]$smterms[[i]]$value)
     }
   })
   
@@ -299,7 +299,7 @@ bootstrapCI <- function(object, which = NULL,
 
   # add information about the values of the covariate
   # and change format
-  for(i in 1:length(listOfCoefs)){
+  for(i in seq_along(listOfCoefs)){
     
     if(isFacSpecEffect[i]){
       
@@ -312,18 +312,18 @@ bootstrapCI <- function(object, which = NULL,
     }
 
     aty <- NA
-    if(isSurface[i] | isFacEffect[i]) aty <- coefs[[1]]$smterms[[i]]$y 
+    if(isSurface[i] || isFacEffect[i]) aty <- coefs[[1]]$smterms[[i]]$y 
     if(isFacSpecEffect[i]) aty <- coefs[[1]]$smterms[[i]][[1]]$y 
 
     # format functional factors
-    if(is.list(listOfCoefs[[i]]) & is.factor(atx)){
+    if(is.list(listOfCoefs[[i]]) && is.factor(atx)){
       
       # combine each factor level
-      listOfCoefs[[i]] <- lapply(1:length(levels(droplevels(atx))),
+      listOfCoefs[[i]] <- lapply(seq_along(levels(droplevels(atx))),
                                  function(faclevnr) t(sapply(listOfCoefs[[i]], function(x) x[faclevnr,])))
       isSurface[i] <- FALSE
       
-    }else if(is.list(listOfCoefs[[i]]) & !isFacSpecEffect[i]){ # effect surfaces
+    }else if(is.list(listOfCoefs[[i]]) && !isFacSpecEffect[i]){ # effect surfaces
       
       listOfCoefs[[i]] <- do.call("rbind", lapply(listOfCoefs[[i]],c))
       
@@ -375,10 +375,10 @@ bootstrapCI <- function(object, which = NULL,
   listOfQuantiles <- vector("list", length(listOfCoefs))
   
   # calculate quantiles
-  for(i in 1:length(listOfCoefs)){
+  for(i in seq_along(listOfCoefs)){
     
     # for matrix object
-    if(is.matrix(listOfCoefs[[i]]) & !is.list(listOfCoefs[[i]])){
+    if(is.matrix(listOfCoefs[[i]]) && !is.list(listOfCoefs[[i]])){
       
       listOfQuantiles[[i]] <- apply(listOfCoefs[[i]], 2, quantile, probs = levels)
       attr(listOfQuantiles[[i]], "x") <- attr(listOfCoefs[[i]], "x")
@@ -404,7 +404,7 @@ bootstrapCI <- function(object, which = NULL,
     lapply(listOfQuantiles[isSurface], 
            function(x){ 
              
-             retL <- lapply(1:nrow(x), function(i) 
+             retL <- lapply(seq_len(nrow(x)), function(i) 
                matrix(x[i,], nrow = length(attr(x, "y"))))
              names(retL) <- levels
              return(retL)
@@ -418,7 +418,7 @@ bootstrapCI <- function(object, which = NULL,
              
              if(is.list(x)){
                
-               for(j in 1:length(x)){
+               for(j in seq_along(x)){
                  
                  if(!is.null(dim(x[[j]]))){
                    rownames(x[[j]]) <- levels
@@ -498,7 +498,7 @@ plot.bootstrapCI <- function(x, which = NULL, pers = TRUE,
                              ylim = NULL, ...)
 {
   
-  stopifnot(class(x) == "bootstrapCI")
+  stopifnot(inherits(x, "bootstrapCI"))
   
   boot_offset <- 0 
   
@@ -512,7 +512,7 @@ plot.bootstrapCI <- function(x, which = NULL, pers = TRUE,
     
   }
   
-  if(is.null(which)) which <- 1:length(x$raw_results)
+  if(is.null(which)) which <- seq_along(x$raw_results)
   
   oldpar <- par(no.readonly = TRUE)
   on.exit(par(oldpar))
@@ -520,7 +520,7 @@ plot.bootstrapCI <- function(x, which = NULL, pers = TRUE,
   if(length(which)>1) par(ask=ask)
   
   # find common range for all effects 
-  if(commonRange & is.null(ylim)){
+  if(commonRange && is.null(ylim)){
     ylim <- range(x$raw_results) 
     if(any(is.infinite(ylim))) ylim <- NULL
   }
@@ -544,11 +544,11 @@ plot.bootstrapCI <- function(x, which = NULL, pers = TRUE,
     if(!is.list(temp_CI)){
       
       if(temp$dim >= 2){
-        temp$value <- split(temp_CI, seq(nrow(temp_CI)))
+        temp$value <- split(temp_CI, seq_len(nrow(temp_CI)))
       }else{ 
         ## temp$dim == 1 like in scalar response with bsignal()
         ## put each fold into one list entry 
-        if(length(x$yind) <= 1 & x$family != "Binomial Distribution (similar to glm)"){ 
+        if(length(x$yind) <= 1 && x$family != "Binomial Distribution (similar to glm)"){ 
           # scalar response and not Binomial
           temp$value <- split(temp_CI, rep(1:x$B_outer, each = length(temp_CI)/x$B_outer))
         }else{
@@ -559,7 +559,7 @@ plot.bootstrapCI <- function(x, which = NULL, pers = TRUE,
       
     }else{
  
-      if(is.null(temp$numberLevels) & is.factor(temp$x)){
+      if(is.null(temp$numberLevels) && is.factor(temp$x)){
         
         ## for time-varying factor effects
         temp$value <- temp_CI
@@ -573,7 +573,7 @@ plot.bootstrapCI <- function(x, which = NULL, pers = TRUE,
       }
     }    
     
-    if(!is.null(temp$dim) && temp$dim == 2 & !is.factor(temp$x)){
+    if(!is.null(temp$dim) && temp$dim == 2 && !is.factor(temp$x)){
       temp$value <- lapply(temp$value, function(xx) 
         matrix(xx, ncol = sqrt(length(xx)), nrow = sqrt(length(xx)), byrow = FALSE) )
     }
@@ -598,7 +598,7 @@ plot.bootstrapCI <- function(x, which = NULL, pers = TRUE,
 print.bootstrapCI <- function(x, ...)
 {
 
-  stopifnot(class(x)=="bootstrapCI")
+  stopifnot(inherits(x, "bootstrapCI"))
 
   cat("\n")
      
