@@ -89,8 +89,8 @@
   if(any(used_bl == "bolsc")) stop("Use bols instead of bolsc with %Xc%.")
   if(any(used_bl == "brandomc")) stop("Use brandom instead of brandomc with %Xc%.")
   if(any(used_bl == "bbsc")) stop("Use bbs instead of bbsc with %Xc%.")
-  if( (!is.null(match.call()$bl1$intercept) &&  match.call()$bl1$intercept != TRUE) |
-      (!is.null(match.call()$bl2$intercept) &&  match.call()$bl2$intercept != TRUE) ){
+  if( (!is.null(match.call()$bl1$intercept) && !isTRUE(match.call()$bl1$intercept)) ||
+      (!is.null(match.call()$bl2$intercept) && !isTRUE(match.call()$bl2$intercept)) ){
     stop("Set intercept = TRUE in base-learners used with %Xc%.")
   }
   
@@ -104,8 +104,8 @@
                mboost_intern(bl2, fun = "model.frame.blg") )
   index1 <- bl1$get_index()
   index2 <- bl2$get_index()
-  if (is.null(index1)) index1 <- 1:nrow(mf)
-  if (is.null(index2)) index2 <- 1:nrow(mf)
+  if (is.null(index1)) index1 <- seq_len(nrow(mf))
+  if (is.null(index2)) index2 <- seq_len(nrow(mf))
   
   mfindex <- cbind(index1, index2)
   index <- NULL
@@ -172,9 +172,9 @@
     X1 <- X1$X
     if (!is.null(l1)) K1 <- l1 * K1
     MATRIX <- options("mboost_useMatrix")$mboost_useMatrix
-    if (MATRIX & !is(X1, "Matrix"))
+    if (MATRIX && !is(X1, "Matrix"))
       X1 <- Matrix(X1)
-    if (MATRIX & !is(K1, "Matrix"))
+    if (MATRIX && !is(K1, "Matrix"))
       K1 <- Matrix(K1)
     
     X2 <- newX2(mf[, bl2$get_names(), drop = FALSE],
@@ -182,9 +182,9 @@
     K2 <- X2$K
     X2 <- X2$X
     if (!is.null(l2)) K2 <- l2 * K2
-    if (MATRIX & !is(X2, "Matrix"))
+    if (MATRIX && !is(X2, "Matrix"))
       X2 <- Matrix(X2)
-    if (MATRIX & !is(K2, "Matrix"))
+    if (MATRIX && !is(K2, "Matrix"))
       K2 <- Matrix(K2)
     suppressMessages(
       X <- kronecker(X1, Matrix(1, ncol = ncol(X2),
@@ -211,7 +211,7 @@
       ## use whole matrices of marginal effects for constraints as Almond suggested  
       C <- t(X) %*% cbind(rep(1, nrow(X)), X1, X2)    
       qr_C <- qr(C)  ## , tol = 1e-10 ## time?
-      if( any(class(qr_C) == "sparseQR") ){
+      if( inherits(qr_C, "sparseQR") ){
         rank_C <- qr_C@Dim[2]
       }else{
         rank_C <- qr_C$rank 
@@ -312,8 +312,8 @@ bl_lin_matrix_a <- function(blg, Xfun, args) {
         # K2 <- args$K2 
         
         #  ## per default do not expand the marginal design matrices 
-        #  expand_index1 <- 1:nrow(X$X1)
-        #  expand_index2 <- 1:nrow(X$X2)
+        #  expand_index1 <- seq_len(nrow(X$X1))
+        #  expand_index2 <- seq_len(nrow(X$X2))
         
         ## weights-matrix W: weights are for single observations in the matrix Y
         ## but the marginal bl work either on columns or rows of Y 
@@ -344,7 +344,7 @@ bl_lin_matrix_a <- function(blg, Xfun, args) {
             if( all(abs(multFactor - multFactor[1] ) < .Machine$double.eps*10^10) ) multFactor <- multFactor[1]
             
             ## case that W and w1w2 just differ by a factor 
-            if( all((W == w1w2)[w1w2 == 0]) & all((W == w1w2)[W == 0]) & ## check positions of zeros 
+            if( all((W == w1w2)[w1w2 == 0]) && all((W == w1w2)[W == 0]) && ## check positions of zeros 
                 length(multFactor) == 1 ){ # check that only 1 multiplicative factor 
               
               ## it is impossible to know whether multFactor is multiplied to w1 or w2! 
@@ -375,8 +375,8 @@ bl_lin_matrix_a <- function(blg, Xfun, args) {
           ### but: this does not work correctly: problem with factor remains 
           #   ## W cannot be computed from w1 and w2, 
           #   ## -> blow up the marginal design matrices and use W with them, 
-          #   expand_index1 <- rep(1:nrow(X$X1), times = nrow(X$X2)) 
-          #   expand_index2 <- rep(1:nrow(X$X2), each = nrow(X$X1))  
+          #   expand_index1 <- rep(seq_len(nrow(X$X1)), times = nrow(X$X2)) 
+          #   expand_index2 <- rep(seq_len(nrow(X$X2)), each = nrow(X$X1))  
           #   ## all( c(W) == weights) is TRUE, ordering of weights must match to blown-up marginal design matrices 
           #   ## standardize weights to compensate for the blow-up of the marginal design-matrices  
           #   #w1 <- c(W) / mean(rowSums(W)) ## for some special cases (e.g. BS on rows): mean(rowSums(W)) == nrow(X$X2)
@@ -783,9 +783,9 @@ NULL
     X1 <- X1$X
     if (!is.null(l1)) K1 <- l1 * K1
     MATRIX <- options("mboost_useMatrix")$mboost_useMatrix
-    if (MATRIX & !is(X1, "Matrix"))
+    if (MATRIX && !is(X1, "Matrix"))
       X1 <- Matrix(X1)
-    if (MATRIX & !is(K1, "Matrix"))
+    if (MATRIX && !is(K1, "Matrix"))
       K1 <- Matrix(K1)
     
     X2 <- newX2(as.data.frame(mf[bl2$get_names()]),
@@ -793,9 +793,9 @@ NULL
     K2 <- X2$K
     X2 <- X2$X
     if (!is.null(l2)) K2 <- l2 * K2
-    if (MATRIX & !is(X2, "Matrix"))
+    if (MATRIX && !is(X2, "Matrix"))
       X2 <- Matrix(X2)
-    if (MATRIX & !is(K2, "Matrix"))
+    if (MATRIX && !is(K2, "Matrix"))
       K2 <- Matrix(K2)
     suppressMessages(
       K <- kronecker(K2, diag(ncol(X1))) +
@@ -912,7 +912,7 @@ NULL
       }
     }
 
-    if(args$lambda1 != 0 & args$lambda2 != 0) 
+    if(args$lambda1 != 0 && args$lambda2 != 0) 
       stop("%A0% can only be used when smoothing parameter is zero for one direction.")
     
     l1 <- args$lambda1
@@ -931,9 +931,9 @@ NULL
     X1 <- X1$X
     if (!is.null(l1)) K1 <- l1 * K1
     MATRIX <- options("mboost_useMatrix")$mboost_useMatrix
-    if (MATRIX & !is(X1, "Matrix"))
+    if (MATRIX && !is(X1, "Matrix"))
       X1 <- Matrix(X1)
-    if (MATRIX & !is(K1, "Matrix"))
+    if (MATRIX && !is(K1, "Matrix"))
       K1 <- Matrix(K1)
     
     X2 <- newX2(as.data.frame(mf[bl2$get_names()]),
@@ -941,9 +941,9 @@ NULL
     K2 <- X2$K
     X2 <- X2$X
     if (!is.null(l2)) K2 <- l2 * K2
-    if (MATRIX & !is(X2, "Matrix"))
+    if (MATRIX && !is(X2, "Matrix"))
       X2 <- Matrix(X2)
-    if (MATRIX & !is(K2, "Matrix"))
+    if (MATRIX && !is(K2, "Matrix"))
       K2 <- Matrix(K2)
     suppressMessages(
       K <- kronecker(K2, diag(ncol(X1))) +
@@ -986,8 +986,8 @@ NULL
   
   index1 <- bl1$get_index()
   index2 <- bl2$get_index()
-  if (is.null(index1)) index1 <- 1:nrow(mf)
-  if (is.null(index2)) index2 <- 1:nrow(mf)
+  if (is.null(index1)) index1 <- seq_len(nrow(mf))
+  if (is.null(index2)) index2 <- seq_len(nrow(mf))
   
   mfindex <- cbind(index1, index2)
   index <- NULL
@@ -1075,7 +1075,7 @@ NULL
       }
     }
     
-    if(args$lambda1 != 0 & args$lambda2 != 0) 
+    if(args$lambda1 != 0 && args$lambda2 != 0) 
       stop("%Xa0% can only be used when smoothing parameter is zero for one direction.")
     
     l1 <- args$lambda1
@@ -1094,9 +1094,9 @@ NULL
     X1 <- X1$X
     if (!is.null(l1)) K1 <- l1 * K1
     MATRIX <- options("mboost_useMatrix")$mboost_useMatrix
-    if (MATRIX & !is(X1, "Matrix"))
+    if (MATRIX && !is(X1, "Matrix"))
       X1 <- Matrix(X1)
-    if (MATRIX & !is(K1, "Matrix"))
+    if (MATRIX && !is(K1, "Matrix"))
       K1 <- Matrix(K1)
     
     X2 <- newX2(mf[, bl2$get_names(), drop = FALSE],
@@ -1104,9 +1104,9 @@ NULL
     K2 <- X2$K
     X2 <- X2$X
     if (!is.null(l2)) K2 <- l2 * K2
-    if (MATRIX & !is(X2, "Matrix"))
+    if (MATRIX && !is(X2, "Matrix"))
       X2 <- Matrix(X2)
-    if (MATRIX & !is(K2, "Matrix"))
+    if (MATRIX && !is(K2, "Matrix"))
       K2 <- Matrix(K2)
     suppressMessages(
       X <- kronecker(X1, Matrix(1, ncol = ncol(X2),
