@@ -135,7 +135,7 @@
 #'   cvr <- applyFolds(mod, folds = folds_bs, grid = 1:75)
 #' 
 #'   ## weights per observation point  
-#'   folds_bs_long <- folds_bs[rep(1:nrow(folds_bs), times = mod$ydim[2]), ]
+#'   folds_bs_long <- folds_bs[rep(seq_len(nrow(folds_bs)), times = mod$ydim[2]), ]
 #'   attr(folds_bs_long, "type") <- "3-fold bootstrap"
 #'   ## compute out-of-bag risk on the 3 folds for 1 to 75 boosting iterations  
 #'   cvr3 <- cvrisk(mod, folds = folds_bs_long, grid = 1:75)
@@ -172,7 +172,7 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
     stop("The folds-matrix must have one row per observed trajectory.")
   }
   
-  if(any(class(object) == "FDboostLong")){ # irregular response
+  if(inherits(object, "FDboostLong")){ # irregular response
     nObs <- length(unique(object$id)) # number of curves
     Gy <- NULL # number of time-points per curve
   }else{ # regular response / scalar response 
@@ -201,7 +201,7 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
   }else{
     
     if(numInt == "Riemann"){ # use the integration scheme specified in applyFolds
-      if(!any(class(object) == "FDboostLong")){
+      if(!inherits(object, "FDboostLong")){
         integration_weights <- as.vector(integrationWeights(X1 = matrix(object$response, 
                                                                         ncol = object$ydim[2]), object$yind))
       }else{
@@ -216,7 +216,7 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
   
   ### get yind in long format
   yindLong <- object$yind
-  if(!any(class(object) == "FDboostLong")){
+  if(!inherits(object, "FDboostLong")){
     yindLong <- rep(object$yind, each = nObs)
   }
   ### compute ("length of each trajectory")^-1 in the response
@@ -235,7 +235,7 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
   
   # Function to suppress the warning of missings in the response
   h <- function(w){
-    if( any( grepl( "response contains missing values;", w) ) ) 
+    if( any( grepl( "response contains missing values;", w, fixed = TRUE) ) ) 
       invokeRestart( "muffleWarning" )  
   }
   
@@ -248,14 +248,14 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
   ## problem with index for bl containing index, and you do not get s for bsignal/bhist
   if(FALSE){
     dathelp2 <- list()
-    for(j in 1:length(object$baselearner)){
+    for(j in seq_along(object$baselearner)){
       dat_bl_j <- object$baselearner[[j]]$get_data() ## object$baselearner[[j]]$model.frame()
       # if the variable is already present, do not add it again
       dathelp2 <- c(dathelp2, dat_bl_j[!names(dat_bl_j) %in% names(dathelp2)])
     }
   }
   
-  if(!any(class(object) == "FDboostLong") & !any(class(object) == "FDboostScalar")){
+  if(!inherits(object, "FDboostLong") && !inherits(object, "FDboostScalar")){
     dathelp[[object$yname]] <- matrix(object$response, ncol=object$ydim[2])
     dathelp$integration_weights <- matrix(integration_weights, ncol=object$ydim[2])
     dathelp$object_id <- object$id
@@ -279,13 +279,13 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
   names_variables <- names_variables[names_variables != nameyind]
   names_variables <- names_variables[names_variables != "ONEx"]
   names_variables <- names_variables[names_variables != "ONEtime"]
-  if(!any(class(object) == "FDboostLong")) names_variables <- c(object$yname, "integration_weights", names_variables)
+  if(!inherits(object, "FDboostLong")) names_variables <- c(object$yname, "integration_weights", names_variables)
   
-  length_variables <- if("FDboostScalar" %in% class(object)) 
+  length_variables <- if(inherits(object, "FDboostScalar")) 
     lapply(dathelp[names_variables], length) else
       lapply(dathelp[names_variables], NROW)
   names_variables_long <- names_variables[ length_variables == length(object$id) ]
-  nothmatrix <- ! sapply(dathelp[names_variables_long], function(x) any(class(x) == "hmatrix" ))
+  nothmatrix <- ! sapply(dathelp[names_variables_long], is.hmatrix)
   names_variables_long <- names_variables_long[ nothmatrix ]
   if(identical(names_variables_long, character(0))) names_variables_long <- NULL
   
@@ -296,16 +296,16 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
   # the probelm with such base-learners is that their data is not contained in object$data
   # using object$baselearner[[j]]$get_data() is difficult as this can be blow up by index for %X%
   singleBls <- gsub("\\s", "", unlist(lapply(strsplit(
-    strsplit(object$formulaFDboost, "~")[[1]][2], # split formula
-                                      "\\+")[[1]], # split additive terms
+    strsplit(object$formulaFDboost, "~", fixed = TRUE)[[1]][2], # split formula
+                                      "+", fixed = TRUE)[[1]], # split additive terms
     function(y) strsplit(y, split = "%.{1,3}%")) # split single baselearners
   )) 
   
   singleBls <- singleBls[singleBls != "1"]
   
-  if(any(!grepl("\\(", singleBls))) 
+  if(any(!grepl("(", singleBls, fixed = TRUE))) 
     stop(paste0("applyFolds can not deal with the following base-learner(s) without brackets: ", 
-                paste(singleBls[!grepl("\\(", singleBls)], collapse = ", ")))
+                toString(singleBls[!grepl("(", singleBls, fixed = TRUE)])))
   
   
   ## check if data includes all variables
@@ -317,11 +317,11 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
     
     # for each missing variable get the first baselearner, which contains the variable
     blWithMissVars <- lapply(names_variables[whMiss], function(w) 
-      unlist(lapply(1:length(object$baselearner), function(i) if(
+      unlist(lapply(seq_along(object$baselearner), function(i) if(
         any( grepl(w, object$baselearner[[i]]$get_names() ) )) return(i))
       )[1])
     
-    stop(paste0("base-learner(s) ", paste(unlist(list(1,2)), collapse = ", "), 
+    stop(paste0("base-learner(s) ", toString(unlist(list(1,2))), 
                 " contain(s) variables, which are not part of the data object."))
     
   }
@@ -330,7 +330,7 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
   fitfct <- function(weights, oobweights){
     
     ## get data according to weights
-    if(any(class(object) == "FDboostLong")){
+    if(inherits(object, "FDboostLong")){
       dat_weights <- reweightData(data = dathelp, vars = names_variables, 
                                   longvars = c(object$yname, nameyind, "integration_weights", names_variables_long),  
                                   weights = weights, idvars = c(attr(object$id, "nameid"), index_names),
@@ -352,10 +352,10 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
     if(any(isFac)){
       namesFac <- names(isFac)[isFac]
       
-      for(i in 1:length(namesFac)){
+      for(i in seq_along(namesFac)){
         
-      if(length(levels(droplevels(dathelp[[namesFac[i]]]))) != 
-         length(levels(droplevels(dat_weights[[namesFac[i]]]))))
+      if(nlevels(droplevels(dathelp[[namesFac[i]]])) !=
+         nlevels(droplevels(dat_weights[[namesFac[i]]])))
         stop(paste0("The factor variable '", namesFac[i], "' has unobserved levels in the training data. ",
                     "Make sure that training data in each fold contains all factor levels."))
         
@@ -403,7 +403,7 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
       }
 
       ## get data according to oobweights
-      if(any(class(object) == "FDboostLong")){
+      if(inherits(object, "FDboostLong")){
         dathelp$lengthTi1 <- c(lengthTi1)
         dat_oobweights <- reweightData(data = dathelp, vars = c(names_variables, "lengthTi1"),  
                                        longvars = c(object$yname, nameyind, 
@@ -449,7 +449,7 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
           invokeRestart( "muffleWarning" )  
       }
       
-      if(any(class(object) == "FDboostLong")){
+      if(inherits(object, "FDboostLong")){
         
         if(numInt == "equal"){ 
           oobwstand <- dat_oobweights$integration_weights * (1/sum(dat_oobweights$integration_weights))
@@ -505,15 +505,15 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
   OOBweights <- matrix(rep(sample_weights, ncol(folds)), ncol = ncol(folds))
   OOBweights[folds > 0] <- 0
   
-  if (all.equal(papply, mclapply) == TRUE) {
-    oobrisk <- papply(1:ncol(folds),
+  if (isTRUE(all.equal(papply, mclapply))) {
+    oobrisk <- papply(seq_len(ncol(folds)),
                       function(i) try(dummyfct(weights = folds[, i],
                                                oobweights = OOBweights[, i]),
                                       silent = TRUE),
                       mc.preschedule = mc.preschedule,
                       ...)
   } else {
-    oobrisk <- papply(1:ncol(folds),
+    oobrisk <- papply(seq_len(ncol(folds)),
                       function(i) try(dummyfct(weights = folds[, i],
                                                oobweights = OOBweights[, i]),
                                       silent = TRUE),
@@ -541,7 +541,7 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
   oobrisk <- t(as.data.frame(oobrisk))
   ## oobrisk <- oobrisk  / colSums(OOBweights[object$id, ]) # is done in dummyfct() 
   colnames(oobrisk) <- grid
-  rownames(oobrisk) <- 1:nrow(oobrisk)
+  rownames(oobrisk) <- seq_len(nrow(oobrisk))
   attr(oobrisk, "risk") <- fam_name
   attr(oobrisk, "call") <- call
   attr(oobrisk, "mstop") <- grid
@@ -656,7 +656,7 @@ applyFolds <- function(object, folds = cv(rep(1, length(unique(object$id))), typ
 #'   cvr2 <- validateFDboost(mod, folds = folds_bs, grid = 1:75)
 #' 
 #'   ## weights per observation point  
-#'   folds_bs_long <- folds_bs[rep(1:nrow(folds_bs), times = mod$ydim[2]), ]
+#'   folds_bs_long <- folds_bs[rep(seq_len(nrow(folds_bs)), times = mod$ydim[2]), ]
 #'   attr(folds_bs_long, "type") <- "3-fold bootstrap"
 #'   ## compute out-of-bag risk on the 3 folds for 1 to 75 boosting iterations  
 #'   cvr3 <- cvrisk(mod, folds = folds_bs_long, grid = 1:75)
@@ -701,9 +701,9 @@ validateFDboost <- function(object, response = NULL,
               msg = "'validateFDboost' is deprecated. Use 'applyFolds' and 'bootstrapCI' instead.")
   
   names_bl <- names(object$baselearner)
-  if(any(grepl("brandomc", names_bl))) message("For brandomc, the transformation matrix Z is fixed over all folds.")
-  if(any(grepl("bolsc", names_bl))) message("For bolsc, the transformation matrix Z is fixed over all folds.")
-  if(any(grepl("bbsc", names_bl))) message("For bbsc, the transformation matrix Z is fixed over all folds.")
+  if(any(grepl("brandomc", names_bl, fixed = TRUE))) message("For brandomc, the transformation matrix Z is fixed over all folds.")
+  if(any(grepl("bolsc", names_bl, fixed = TRUE))) message("For bolsc, the transformation matrix Z is fixed over all folds.")
+  if(any(grepl("bbsc", names_bl, fixed = TRUE))) message("For bbsc, the transformation matrix Z is fixed over all folds.")
   
   type <- attr(folds, "type")
   if(is.null(type)) type <- "unknown"
@@ -715,7 +715,7 @@ validateFDboost <- function(object, response = NULL,
     stop("The folds-matrix must have one row per observed trajectory.")
   }
   
-  if(any(class(object) == "FDboostLong")){ # irregular response
+  if(inherits(object, "FDboostLong")){ # irregular response
     nObs <- length(unique(object$id)) # number of curves
     Gy <- NULL # number of time-points per curve
   }else{ # regular response / scalar response 
@@ -739,7 +739,7 @@ validateFDboost <- function(object, response = NULL,
   # intWeights <- model.weights(object) 
   # weights are rescaled in mboost, see mboost:::rescale_weights  
   if(!is.null(object$callEval$numInt) && object$callEval$numInt == "Riemann"){
-    if(!any(class(object) == "FDboostLong")){
+    if(!inherits(object, "FDboostLong")){
       intWeights <- as.vector(integrationWeights(X1 = matrix(object$response, 
                               ncol = object$ydim[2]), object$yind))
     }else{
@@ -755,13 +755,13 @@ validateFDboost <- function(object, response = NULL,
   
   # Function to suppress the warning of missings in the response
   h <- function(w){
-    if( any( grepl( "response contains missing values;", w) ) ) 
+    if( any( grepl( "response contains missing values;", w, fixed = TRUE) ) ) 
       invokeRestart( "muffleWarning" )  
   }
   
   ### get yind in long format
   yindLong <- object$yind
-  if(!any(class(object) == "FDboostLong")){
+  if(!inherits(object, "FDboostLong")){
     yindLong <- rep(object$yind, each = nObs)
   }
   ### compute ("length of each trajectory")^-1 in the response
@@ -783,7 +783,7 @@ validateFDboost <- function(object, response = NULL,
     nameyind <- attr(object$yind, "nameyind")
     dathelp[[nameyind]] <- object$yind
     
-    if(!any(class(object) == "FDboostLong") & !any(class(object) == "FDboostScalar")){
+    if(!inherits(object, "FDboostLong") && !inherits(object, "FDboostScalar")){
       dathelp[[object$yname]] <- matrix(object$response, ncol = Gy)
     }else{
       dathelp[[object$yname]] <- object$response
@@ -800,8 +800,8 @@ validateFDboost <- function(object, response = NULL,
     # Using the offset of object with the following settings 
     # call$control <- boost_control(risk="oobag")
     # call$oobweights <- oobweights[id]
-    if(refitSmoothOffset == FALSE && is.null(call$offset) ){
-      if(!any(class(object) == "FDboostLong")){
+    if(!refitSmoothOffset && is.null(call$offset) ){
+      if(!inherits(object, "FDboostLong")){
         call$offset <- matrix(object$offset, ncol = Gy)[1, ]
       }else{
         call$offset <- object$offset
@@ -895,11 +895,11 @@ validateFDboost <- function(object, response = NULL,
   
   ### computation of models on partitions of data
   if(Sys.info()["sysname"]=="Linux"){
-    modRisk <- mclapply(1:ncol(folds),
+    modRisk <- mclapply(seq_len(ncol(folds)),
                         function(i) dummyfct(weights = folds[, i],
                                              oobweights = OOBweights[, i]), ...)
   }else{
-    modRisk <- mclapply(1:ncol(folds),
+    modRisk <- mclapply(seq_len(ncol(folds)),
                         function(i) dummyfct(weights = folds[, i], 
                                              oobweights = OOBweights[, i]), mc.cores = 1)
   }
@@ -908,13 +908,13 @@ validateFDboost <- function(object, response = NULL,
   # str(modRisk, max.level=5)
   
   # check whether model fit worked in all iterations
-  modFitted <- sapply(modRisk, function(x) class(x) == "list")
+  modFitted <- sapply(modRisk, is.list)
   if(any(!modFitted)){
     
     # stop() or warning()?
     if(sum(!modFitted) > sum(modFitted)) warning("More than half of the models could not be fitted.")
     
-    warning("Model fit did not work in fold ", paste(which(!modFitted), collapse = ", "))
+    warning("Model fit did not work in fold ", toString(which(!modFitted)))
     modRisk <- modRisk[modFitted]
     OOBweights <- OOBweights[,modFitted]   
     folds <- folds[,modFitted]
@@ -956,18 +956,18 @@ validateFDboost <- function(object, response = NULL,
   }
   
   ## only makes sense for type="curves" with leaving-out one curve per fold!!
-  if(grepl( "curves", type)){
+  if(grepl( "curves", type, fixed = TRUE)){
     # predict response for all mstops in grid out of bag
     # predictions for each response are in a vector!
     oobpreds0 <- lapply(modRisk, function(x) x$predGrid)
     oobpreds <- matrix(nrow = nrow(oobpreds0[[1]]), ncol = ncol(oobpreds0[[1]]))
     
-    if(any(class(object) == "FDboostLong")){
-      for(i in 1:length(oobpreds0)){ # i runs over observed trajectories, i.e. over id 
+    if(inherits(object, "FDboostLong")){
+      for(i in seq_along(oobpreds0)){ # i runs over observed trajectories, i.e. over id
         oobpreds[id == i, ]  <- oobpreds0[[i]][id == i, ] 
       }
     }else{
-      for(j in 1:length(oobpreds0)){
+      for(j in seq_along(oobpreds0)){
         oobpreds[folds[ , j] == 0] <- oobpreds0[[j]][folds[ , j] == 0] 
       }
     }
@@ -1008,7 +1008,7 @@ validateFDboost <- function(object, response = NULL,
     
     ### estimates of coefficients
     timeHelp <- seq(min(modRisk[[1]]$mod$yind), max(modRisk[[1]]$mod$yind), l = 40)
-    for(l in 1:length(modRisk[[1]]$mod$baselearner)){
+    for(l in seq_along(modRisk[[1]]$mod$baselearner)){
       # estimate the coefficients for the model of the first fold
       my_coef <- coef(modRisk[[1]]$mod[optimalMstop], 
            which = l, n1 = 40, n2 = 20, n3 = 15, n4 = 10)$smterms[[1]]
@@ -1023,7 +1023,7 @@ validateFDboost <- function(object, response = NULL,
         attr(coefCV[[l]]$value, "offset") <- NULL # as offset is the same within one model
         
         # add estimates for the models of the other folds
-        coefCV[[l]]$value <- lapply(1:length(modRisk), function(g){
+        coefCV[[l]]$value <- lapply(seq_along(modRisk), function(g){
           ret <- coef(modRisk[[g]]$mod[optimalMstop], 
                       which = l, n1 = 40, n2 = 20, n3 = 15, n4 = 10)$smterms[[1]]$value
           #         if(l==1){
@@ -1036,7 +1036,7 @@ validateFDboost <- function(object, response = NULL,
         ## %X% with numberLevels coefficient values in a list
         ## lapply(1:coefCV[[l]]$numberLevels, function(x) coefCV[[l]][[x]]$value)
         for(j in 1:coefCV[[l]]$numberLevels){
-          coefCV[[l]][[j]]$value <- lapply(1:length(modRisk), function(g){
+          coefCV[[l]][[j]]$value <- lapply(seq_along(modRisk), function(g){
             ret <- coef(modRisk[[g]]$mod[optimalMstop], 
                         which = l, n1 = 40, n2 = 20, n3 = 15, n4 = 10)$smterms[[1]][[j]]$value
             attr(ret, "offset") <- NULL # as offset is the same within one model
@@ -1048,7 +1048,7 @@ validateFDboost <- function(object, response = NULL,
     }
     
     ## predict offset
-    offset <- sapply(1:length(modRisk), function(g){
+    offset <- sapply(seq_along(modRisk), function(g){
       # offset is vector of length yind or numeric of length 1 for constant offset
       ret <- modRisk[[g]]$mod$predictOffset(time = timeHelp)
       if( length(ret) == 1 & length(object$yind) > 1 ) ret <- rep(ret, length(timeHelp))
@@ -1061,14 +1061,14 @@ validateFDboost <- function(object, response = NULL,
     
     ### predictions of terms based on the coefficients for each model
     # only makes sense for type="curves" with leaving-out one curve per fold!!
-    if(grepl("curves", type)){
+    if(grepl("curves", type, fixed = TRUE)){
       for(l in 1:(length(modRisk[[1]]$mod$baselearner)+1)){
-        predCV[[l]] <- t(sapply(1:length(modRisk), function(g){
+        predCV[[l]] <- t(sapply(seq_along(modRisk), function(g){
           if(l == 1){ # save offset of model
             # offset is vector of length yind or numeric of length 1 for constant offset
             ret <- modRisk[[g]]$mod[optimalMstop]$predictOffset(object$yind) 
             # regular data or scalar response
-            if(!any(class(object) == "FDboostLong")){
+            if(!inherits(object, "FDboostLong")){
               if( length(ret) == 1 ) ret <- rep(ret, modRisk[[1]]$mod$ydim[2])
             # irregular data
             }else{ 
@@ -1077,13 +1077,13 @@ validateFDboost <- function(object, response = NULL,
           }else{ # other effects
             ret <- predict(modRisk[[g]]$mod[optimalMstop], which = l-1) # model g
             if(!(l-1) %in% selected(modRisk[[g]]$mod[optimalMstop]) ){ # effect was never chosen
-              if(!any(class(object) == "FDboostLong")){
+              if(!inherits(object, "FDboostLong")){
                 ret <- matrix(0, ncol=modRisk[[1]]$mod$ydim[2], nrow=modRisk[[1]]$mod$ydim[1])
               }else{
                 ret <- matrix(0, nrow = length(object$id), ncol=1)
               } 
             }
-            if(!any(class(object) == "FDboostLong")){
+            if(!inherits(object, "FDboostLong")){
               ret <- ret[g,] # save g-th row = preds for g-th observations
             }else{
               ret <- ret[object$id == g] # save preds of g-th observations
@@ -1112,7 +1112,7 @@ validateFDboost <- function(object, response = NULL,
               oobrisk0 = oobrisk0, 
               oobmse0 = oobmse0,
               oobmrd0 = oobmrd0, 
-              format = if(any(class(object) == "FDboostLong")) "FDboostLong" else "FDboost", 
+              format = if(inherits(object, "FDboostLong")) "FDboostLong" else "FDboost", 
               fun_ret = if(is.null(fun)) NULL else lapply(modRisk, function(x) x$fun_ret) )
   
   rm(modRisk)
@@ -1248,7 +1248,7 @@ plot.validateFDboost <- function(x, riskopt=c("mean", "median"),
             c(min(c(0, ylim[1] * ifelse(ylim[1] < 0, 2, 0.5))), 
               riskMean[paste(mOptMean)]), lty = 2)
       legend("topright", legend=paste(c(mOptMean)),
-             lty=c(2), col=c("black"))
+             lty=2, col="black")
       
     }
 
@@ -1261,7 +1261,7 @@ plot.validateFDboost <- function(x, riskopt=c("mean", "median"),
               riskMedian[paste(mOptMedian)]), lty = 2)
       
       legend("topright", legend=paste(c(mOptMedian)),
-             lty=c(2), col=c("black"))
+             lty=2, col="black")
     }
     
   }
@@ -1287,7 +1287,7 @@ plot.validateFDboost <- function(x, riskopt=c("mean", "median"),
   }
     
   # Plot the predictions for the optimal mstop
-  if(4 %in% which | 5 %in% which){
+  if(4 %in% which || 5 %in% which){
     
     if(!is.null(x$oobpreds)){
       response <- x$response
@@ -1354,9 +1354,9 @@ plotPredCoef <- function(x, which = NULL, pers = TRUE,
                          probs = c(0.25, 0.5, 0.75), # quantiles of variables to use for plotting
                          ylim = NULL, ...){
   
-  stopifnot(any(class(x) == "validateFDboost"))
+  stopifnot(inherits(x, "validateFDboost"))
 
-  if(is.null(which)) which <- 1:length(x$coefCV)
+  if(is.null(which)) which <- seq_along(x$coefCV)
   
   oldpar <- par(no.readonly = TRUE)
   on.exit(par(oldpar))
@@ -1365,7 +1365,7 @@ plotPredCoef <- function(x, which = NULL, pers = TRUE,
   
   if(terms){
     
-    if(all(which == 1:length(x$coefCV))){
+    if(all(which == seq_along(x$coefCV))){
       which <- 1:(length(x$coefCV)+1)
     }else{
       which <- which + 1 
@@ -1376,7 +1376,7 @@ plotPredCoef <- function(x, which = NULL, pers = TRUE,
       return(NULL)
     }
     
-    if(commonRange & is.null(ylim)){ 
+    if(commonRange && is.null(ylim)){ 
       ylim <- range(x$predCV[which])
     }
     
@@ -1387,7 +1387,7 @@ plotPredCoef <- function(x, which = NULL, pers = TRUE,
         
         funplot(x$yind, unlist(x$predCV[[l]]), id=x$id, col="white", 
                 main=names(x$predCV)[l], xlab=attr(x$yind, "nameyind"), ylab="coef", ylim=ylim, ...)
-        for(i in 1:length(x$predCV[[l]])){
+        for(i in seq_along(x$predCV[[l]])){
           lines(x$yind[x$id==i], x$predCV[[l]][[i]], lwd=1, col=i)
           if(showNumbers){
             points(x$yind[x$id==i], x$predCV[[l]][[i]], type="p", pch=paste0(i))
@@ -1407,7 +1407,7 @@ plotPredCoef <- function(x, which = NULL, pers = TRUE,
     
   }else{ # plot coefficients
     
-    if(commonRange & is.null(ylim)){
+    if(commonRange && is.null(ylim)){
       if(length(x$yind)>1){
         if(!any(sapply(lapply(x$coefCV[which], function(x) x$value), is.null))){
           ylim <- range(lapply(x$coefCV[which], function(x) x$value)) 
@@ -1561,8 +1561,8 @@ plot_bootstrapped_coef <- function(temp, l,
     quanty <- quantile(temp$y, probs=probs, type=1)
     
     # set lower triangular matrix to NA for historic effect
-    if(grepl("bhist", temp$main)){
-      for(k in 1:length(temp$value)){
+    if(grepl("bhist", temp$main, fixed = TRUE)){
+      for(k in seq_along(temp$value)){
         temp$value[[k]][temp$value[[k]]==0] <- NA
       }
     }
@@ -1575,7 +1575,7 @@ plot_bootstrapped_coef <- function(temp, l,
       # plot coefficient surfaces at different pointwise quantiles
       if(pers){ 
         matvec <- sapply(temp$value, c)
-        for(k in 1:length(probs)){
+        for(k in seq_along(probs)){
           
           tempZ <- matrix(apply(matvec, 1, quantile, probs=probs[k], na.rm=TRUE), ncol=length(temp$x))
           
@@ -1585,14 +1585,14 @@ plot_bootstrapped_coef <- function(temp, l,
                                    xlab=paste("\n", temp$xlab), ylab=paste("\n", temp$ylab), 
                                    zlab=paste("\n", "coef"), 
                                    zlim=if(any(is.null(ylim))) range(matvec, na.rm=TRUE) else ylim,  
-                                   main=paste(temp$main, " at ", probs[k]*100, "%-quantile", sep=""), 
+                                   main=paste0(temp$main, " at ", probs[k]*100, "%-quantile"), 
                                    col=getColPersp(tempZ)))
         
         }
         
       }else{ # do 2-dim plots
 
-        # for(j in 1:length(quanty)){ 
+        # for(j in seq_along(quanty)){
         #   
         #   myCol <- sapply(temp$value, function(x) x[, quanty[j]==temp$y]) # first column
         #   
@@ -1602,7 +1602,7 @@ plot_bootstrapped_coef <- function(temp, l,
         #   
         # } # end loop over quanty
         # 
-        # for(j in 1:length(quantx)){  
+        # for(j in seq_along(quantx)){
         #   myRow <- sapply(temp$value, function(x) x[quantx[j]==temp$x, ]) # first column
         #   
         #   plot_curves(x_i = temp$x, y_i = myRow, xlab_i = temp$xlab, 
@@ -1612,7 +1612,7 @@ plot_bootstrapped_coef <- function(temp, l,
         # }
         
         matvec <- sapply(temp$value, c)
-        for(k in 1:length(probs)){
+        for(k in seq_along(probs)){
           
           tempZ <- matrix(apply(matvec, 1, quantile, probs=probs[k], na.rm=TRUE), ncol=length(temp$x))
           
@@ -1620,7 +1620,7 @@ plot_bootstrapped_coef <- function(temp, l,
                        myargs=list(x=temp$y, y=temp$x, z=t(tempZ), xlab=paste("\n", temp$xlab), 
                                    ylab=paste("\n", temp$ylab), zlim=c(min(matvec, na.rm=TRUE),
                                                                        max(matvec, na.rm=TRUE)),
-                                   main=paste(temp$main, " at ", probs[k]*100, "%-quantile", sep=""), 
+                                   main=paste0(temp$main, " at ", probs[k]*100, "%-quantile"), 
                                    col = heat.colors(length(temp$x)^2) 
                                    )
           )
@@ -1633,7 +1633,7 @@ plot_bootstrapped_coef <- function(temp, l,
       
     }else{ # temp$x is factor
       
-      for(j in 1:length(quantx)){ 
+      for(j in seq_along(quantx)){
         
         # impute matrix of 0 if effect was never chosen
         temp$value[sapply(temp$value, function(x) is.null(dim(x)))] <- list(matrix(0, ncol=20, nrow=length(quantx)))
@@ -1643,7 +1643,7 @@ plot_bootstrapped_coef <- function(temp, l,
           myRow <- t(temp$value[[which(quantx[j]==temp$x)]])
                      
           plot_curves(x_i = temp$y, y_i = myRow, xlab_i = temp$ylab, 
-                      main_i = paste(temp$main, " at ", temp$xlab,"=" ,quantx[j], sep = ""), 
+                      main_i = paste0(temp$main, " at ", temp$xlab,"=" ,quantx[j]), 
                       ylim_i = ylim)
           
         }else{
@@ -1651,8 +1651,8 @@ plot_bootstrapped_coef <- function(temp, l,
           myRow <- sapply(temp$value, function(x) x[quantx[j]==temp$x & quantz[j]==temp$z, ]) # first column
           
           plot_curves(x_i = temp$y, y_i = myRow, xlab_i = temp$ylab, 
-                      main_i = paste(temp$main, " at ", temp$xlab, "=" , quantx[j], ", " , 
-                                     temp$zlab, "=", quantz[j], sep = ""), 
+                      main_i = paste0(temp$main, " at ", temp$xlab, "=" , quantx[j], ", " , 
+                                     temp$zlab, "=", quantz[j]), 
                       ylim_i = ylim)
         } 
       }
@@ -1675,9 +1675,9 @@ cvrisk.FDboost <- function(object, folds = cvLong(id=object$id, weights=model.we
   if(!length(unique(object$offset)) == 1) message("The smooth offset is fixed over all folds.")
   
   names_bl <- names(object$baselearner)
-  if(any(grepl("brandomc", names_bl))) message("For brandomc, the transformation matrix Z is fixed over all folds.")
-  if(any(grepl("bolsc", names_bl))) message("For bolsc, the transformation matrix Z is fixed over all folds.")
-  if(any(grepl("bbsc", names_bl))) message("For bbsc, the transformation matrix Z is fixed over all folds.")
+  if(any(grepl("brandomc", names_bl, fixed = TRUE))) message("For brandomc, the transformation matrix Z is fixed over all folds.")
+  if(any(grepl("bolsc", names_bl, fixed = TRUE))) message("For bolsc, the transformation matrix Z is fixed over all folds.")
+  if(any(grepl("bbsc", names_bl, fixed = TRUE))) message("For bbsc, the transformation matrix Z is fixed over all folds.")
   
   class(object) <- "mboost"
   
@@ -1713,7 +1713,7 @@ cvLong <- function(id, weights = rep(1, l=length(id)),
                 B = B, prob = prob, strata = strata)
     foldsLong <- folds[id, , drop = FALSE] * weights
   }
-  attr(foldsLong, "type") <- paste(B, "-fold ", type, sep = "")  
+  attr(foldsLong, "type") <- paste0(B, "-fold ", type)
   return(foldsLong)
   
 }
@@ -1739,7 +1739,7 @@ cvMa <- function(ydim, weights = rep(1, l = ydim[1] * ydim[2]),
   if ( (nrowY * ncolY) != n) stop("The arguments weights and ydim do not match.")
   
   ## cvMa is only a wrapper for cvLong
-  foldsMa <- cvLong(id = rep(1:nrowY, times = ncolY), weights = weights, 
+  foldsMa <- cvLong(id = rep(seq_len(nrowY), times = ncolY), weights = weights, 
                     type = type, B=B, prob = 0.5, strata = NULL) 
   return(foldsMa)
 }
