@@ -15,7 +15,7 @@
 #' @param id specify to which curve the point belongs to, id from 1, 2, ..., n.  
 #' @param x matrix of functional covariate, each trajectory is in one row 
 #' @param argvals set of argument values, i.e., the common gird at which the functional covariate 
-#' is observed, by default \code{1:ncol(x)}
+#' is observed, by default \code{seq_len(ncol(x))}
 #' @param timeLab name of the time axis, by default \code{t}
 #' @param idLab name of the id variable, by default \code{wideIndex}
 #' @param xLab name of the functional variable, by default NULL
@@ -57,7 +57,7 @@
 #' # ids and times in the time id matrix 
 #' # for bhistx baselearner, there may be an additional id variable for the tensor product
 #' newdat <- reweightData(data = list(hmat = myhmatrix, 
-#'   repIDx = rep(1:nrow(attr(myhmatrix,'x')), length(attr(myhmatrix,"argvals")))), 
+#'   repIDx = rep(seq_len(nrow(attr(myhmatrix,'x'))), length(attr(myhmatrix,"argvals")))), 
 #'   vars = "hmat", index = c(1,1,2), idvars="repIDx")
 #' length(newdat$repIDx) 
 #' 
@@ -70,19 +70,19 @@
 #' @return An matrix object of type \code{"hmatrix"}
 #'  
 #' @export
-hmatrix <- function(time, id, x, argvals=1:ncol(x), 
+hmatrix <- function(time, id, x, argvals=seq_len(ncol(x)), 
                     timeLab="t", idLab="wideIndex", xLab="x", argvalsLab="s"){
    
   ## check that id is integer valued containing 1, 2, 3, ..., n 
   ## and that x has n rows
-  stopifnot( all(sort(unique(id)) == 1:nrow(x)) )  
+  stopifnot( all(sort(unique(id)) == seq_len(nrow(x))) )  
   stopifnot(length(time)==length(id))
     
   # convert x to a matrix, especially if x is of class AsIs
   x <- matrix(x, ncol=ncol(x), nrow=nrow(x))  
    
   #### check argvals and x
-  if( any(duplicated(argvals)) ){
+  if(anyDuplicated(argvals) > 0){
     stop("argvals contains duplicates.")
   } 
   if( is.unsorted(argvals) ){
@@ -258,7 +258,7 @@ is.hmatrix <- function(object){
   if(missing(j) || is.symbol(j)){ 
     
     tempId <- r[ ,2] # get the id of the corresponding rows
-    tempId <- (1:length(unique(tempId)))[factor(tempId)]  # transform the id to 1, 2, 3, ...        
+    tempId <- (seq_along(unique(tempId)))[factor(tempId)]  # transform the id to 1, 2, 3, ...
     
     return( hmatrix(time=r[ ,1], id=tempId, 
                   x=xAttr$x[unique(r[ ,2]), , drop=FALSE], argvals = xAttr$argvals, 
@@ -332,7 +332,7 @@ subset_hmatrix <- function(x, index, compress = TRUE)
     resMat <- rbind(resMat, 
                     matrix(c(rep(t, sum(idInT)), # for time points in hmatrix
                              index[idInT], # for id in hmatrix
-                             (1:length(index))[idInT]), # for idvars 
+                             (seq_along(index))[idInT]), # for idvars
                            ncol=3))
     
   }
@@ -345,7 +345,7 @@ subset_hmatrix <- function(x, index, compress = TRUE)
     # id with duplicates
     idvars <- c(factor(resMat[,2])) 
     # correct ordering
-    idvars <- (1:length(unique(idvars)))[factor(idvars)] 
+    idvars <- (seq_along(unique(idvars)))[factor(idvars)]
     
     # rewrite index for actual matrix
     index <- unique(index)
