@@ -78,7 +78,7 @@ print.FDboost <- function(x, ...) {
 #'  Takes a fitted \code{FDboost}-object produced by \code{\link{FDboost}()} and produces 
 #'  predictions given a new set of values for the model covariates or the original 
 #'  values used for the model fit. This is a wrapper
-#'  function for \code{\link[mboost:methods]{predict.mboost}()}
+#'  function for \code{\link[mboost]{predict.mboost}()}
 #' 
 #' @param object a fitted \code{FDboost}-object
 #' @param newdata a named list or a data frame containing the values of the model 
@@ -94,7 +94,7 @@ print.FDboost <- function(x, ...) {
 #' @param toFDboost logical, defaults to \code{TRUE}. In case of regular response in wide format 
 #' (i.e. response is supplied as matrix): should the predictions be returned as matrix, or list 
 #' of matrices instead of vectors
-#' @param ...  additional arguments passed on to \code{\link[mboost:methods]{predict.mboost}()}.
+#' @param ...  additional arguments passed on to \code{\link[mboost]{predict.mboost}()}.
 #' 
 #' @seealso \code{\link{FDboost}} for the model fit 
 #' and \code{\link{plotPredicted}} for a plot of the observed values and their predictions.
@@ -104,16 +104,16 @@ print.FDboost <- function(x, ...) {
 # predict function: wrapper for predict.mboost()
 predict.FDboost <- function(object, newdata = NULL, which = NULL, toFDboost = TRUE, ...){
   
-  stopifnot(any(class(object) == "FDboost")) 
+  stopifnot(inherits(object, "FDboost"))
   # print("Prediction FDboost") 
   dots <- list(...)
   
   # toFDboost is only meaningful for array-data
-  if(any(class(object) == "FDboostScalar") |  any(class(object) == "FDboostLong")) toFDboost <- FALSE
+  if(inherits(object, c("FDboostScalar", "FDboostLong"))) toFDboost <- FALSE
 
   if(!is.null(dots$aggregate) && dots$aggregate[1] != "sum"){
     if(length(which) > 1 ) stop("For aggregate != 'sum', only one effect, or which=NULL are possible.")
-    if(toFDboost & class(object)[1] == "FDboost"){ 
+    if(toFDboost && class(object)[1] == "FDboost"){ 
       toFDboost <- FALSE
       warning("Set toFDboost to FALSE, as aggregate != 'sum'. Prediction is in long vector.")
     }
@@ -146,11 +146,11 @@ predict.FDboost <- function(object, newdata = NULL, which = NULL, toFDboost = TR
       # try to get more reliable information on n (number of trajectories)
       # and on lengthYind (length of time)
       # using the hmatrix-objects in newdata if available
-      if(is.list(newdata) | is.data.frame(newdata)){
+      if(is.list(newdata) || is.data.frame(newdata)){
         classes <- lapply(newdata, class)
         alln <- c()
         alllengthYind <- c()
-        for(i in 1:length(classes)){
+        for(i in seq_along(classes)){
           if( any(classes[[i]] == "hmatrix" ) ){
             # number of trajectories
             n <- length(unique(newdata[[i]][,2]) ) 
@@ -185,10 +185,10 @@ predict.FDboost <- function(object, newdata = NULL, which = NULL, toFDboost = TR
       
       n <- 1
       lengthYind <- length(newdata[[nameyind]])
-      if(is.list(newdata) | is.data.frame(newdata)){
+      if(is.list(newdata) || is.data.frame(newdata)){
         classes <- lapply(newdata, class)
         alllengthYind <- c(lengthYind)
-        for(i in 1:length(classes)){
+        for(i in seq_along(classes)){
           if( any(classes[[i]] == "hmatrix" ) ){
             # total number of observation points
             lengthYind <- length(newdata[[i]][,1])
@@ -220,7 +220,7 @@ predict.FDboost <- function(object, newdata = NULL, which = NULL, toFDboost = TR
     posBconc <- grep("bconcurrent(", names(object$baselearner), fixed = TRUE)
     posBhist <- grep("bhist(", names(object$baselearner), fixed = TRUE)
     whichHelp <- which
-    if(is.null(which)) whichHelp <- 1:length(object$baselearner)
+    if(is.null(which)) whichHelp <- seq_along(object$baselearner)
     posBsignal <- whichHelp[whichHelp %in% posBsignal]
     posBconc <- whichHelp[whichHelp %in% posBconc]
     posBhist <- whichHelp[whichHelp %in% posBhist]
@@ -232,9 +232,9 @@ predict.FDboost <- function(object, newdata = NULL, which = NULL, toFDboost = TR
         indname <- attr(object$baselearner[[i]]$get_data()[[xname]], "indname")  # does not work for %X% 
         ## if two ore more base-learners are connected by %X%, find the functional variable 
         ## the loop is necessary if more than one functioal covaraites are used in the same bl
-        if(grepl("%X", names(object$baselearner)[i])){
-          form <- strsplit(object$baselearner[[i]]$get_call(), "%X")[[1]]
-          findFun <- grepl("bhist", form) | grepl("bconcurrent", form) | grepl("bsignal", form) | grepl("bfpc", form)
+        if(grepl("%X", names(object$baselearner)[i], fixed = TRUE)){
+          form <- strsplit(object$baselearner[[i]]$get_call(), "%X", fixed = TRUE)[[1]]
+          findFun <- grepl("bhist", form, fixed = TRUE) | grepl("bconcurrent", form, fixed = TRUE) | grepl("bsignal", form, fixed = TRUE) | grepl("bfpc", form, fixed = TRUE)
           xname <- c()
           indname <- c()
           for(j in which(findFun)){
@@ -253,7 +253,7 @@ predict.FDboost <- function(object, newdata = NULL, which = NULL, toFDboost = TR
           indnameY <- NULL
         }
 
-        for(j in 1:length(xname)){
+        for(j in seq_along(xname)){
           attr(newdata[[xname[j]]], "indname") <- indname[j]
           attr(newdata[[xname[j]]], "xname") <- xname[j]
           attr(newdata[[xname[j]]], "signalIndex") <-  if(indname[j]!="xindDefault") newdata[[indname[j]]] else seq(0,1,l=ncol(newdata[[xname[j]]]))
@@ -282,14 +282,14 @@ predict.FDboost <- function(object, newdata = NULL, which = NULL, toFDboost = TR
     # offset of length>1 is not used in prediction, 
     # important when offset=NULL in FDboost() but not in mboost()
     muffleWarning1 <- function(w){
-      if( any( grepl( "User-specified offset is not a scalar", w) ) )
+      if( any( grepl("User-specified offset is not a scalar", w, fixed = TRUE) ) )
         invokeRestart( "muffleWarning" )  
     }
 
     ## predict all effects together, model-inherent offset is included automatically
     if(is.null(which)){
 
-      if(is.null(object$offsetFDboost) & !is.null(object$offsetMboost) ){ 
+      if(is.null(object$offsetFDboost) && !is.null(object$offsetMboost) ){ 
         # offset=NULL in FDboost, but not in mboost
         ## suppress the warning that the offset cannot be used if offset=NULL in FDboost
         ## as offset is predicted and included in prediction 
@@ -438,7 +438,7 @@ fitted.FDboost <- function(object, toFDboost = TRUE, ...) {
   
   if (length(args) == 0) {
     ## give back matrix for regular response and toFDboost == TRUE
-    if(toFDboost & !any(class(object) == "FDboostScalar") & !any(class(object) == "FDboostLong") ){
+    if(toFDboost && !inherits(object, "FDboostScalar") && !inherits(object, "FDboostLong") ){
       ret <- matrix(object$fitted(), nrow = object$ydim[1])
     }else{ # give back a long vector
       ret <- object$fitted()
@@ -478,8 +478,10 @@ fitted.FDboost <- function(object, toFDboost = TRUE, ...) {
 ### residuals (the current negative gradient)
 residuals.FDboost <- function(object, ...){
   
-  if(!any(class(object)=="FDboostLong")){
-    resid <- matrix(object$resid(), nrow=object$ydim[1])
+  if(!inherits(object, "FDboostLong")){
+    resid <- matrix(object$resid())
+    ydim <- ifelse(is.null(object$ydim[1]), NROW(resid), object$ydim[1])
+    resid <- matrix(resid, nrow = ydim)
     resid[is.na(object$response)] <- NA 
   }else{
     resid <- object$resid()
@@ -502,7 +504,7 @@ residuals.FDboost <- function(object, ...){
 #' If \code{raw = TRUE} the coefficients of the model are returned. 
 #' @param which a subset of base-learners for which the coefficients
 #' should be computed (numeric vector), 
-#' defaults to NULL which is the same as \code{which=1:length(object$baselearner)}.
+#' defaults to NULL which is the same as \code{which=seq_along(object$baselearner)}.
 #' In the special case of \code{which=0}, only the coefficients of the offset are returned.
 #' @param computeCoef defaults to \code{TRUE}, if \code{FALSE} only the names of the terms are returned
 #' @param returnData return the dataset which is used to get the coefficient estimates as 
@@ -562,7 +564,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
     ret$offset$main <- "offset"
     
     # For the special case of which=0, only return the coefficients of the offset
-    if(!is.null(which) & length(which)==1 && which==0){
+    if(!is.null(which) && length(which)==1 && which==0){
       if(computeCoef){
         return(ret)
       }else{
@@ -570,7 +572,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
       }  
     }
     
-    if(is.null(which)) which <- 1:length(object$baselearner)
+    if(is.null(which)) which <- seq_along(object$baselearner)
     
     ## special case of ~1 intercept specification with scalar response
     if( inherits(object, "FDboostScalar") && 
@@ -601,7 +603,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
         numberLevels <- 1  
 
         ### generate data in the case of an bhistx()-bl
-        if(grepl("bhistx", trm$get_call())){
+        if(grepl("bhistx", trm$get_call(), fixed = TRUE)){
           ng <- n2
           # get hmatrix-object
           position_hmatrix <- which(sapply(trm$model.frame(), is.hmatrix))
@@ -612,10 +614,10 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
           tvals <- seq(min(tvals), max(tvals), length = ng)
           tvals <- rep(tvals, each = ng)
 
-          if( grepl("%X", trm$get_call()) ){
+          if( grepl("%X", trm$get_call(), fixed = TRUE) ){
             split_bl <- strsplit(trm$get_call(), split = "%.{1,3}%")[[1]]
             ## save the position of bhistx() 
-            position_bhistx <- which(grepl("bhistx", split_bl))
+            position_bhistx <- grep("bhistx", split_bl, fixed = TRUE)
             
             if(length(split_bl) == 2){ # one %X%
               if(position_bhistx == 1){
@@ -665,7 +667,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
           attr(d, "ym") <- seq(min(tvals), max(tvals), length = ng)
           
           ## for a tensor product term: add the scalar factors to d
-          if( grepl("%X", trm$get_call()) ){
+          if( grepl("%X", trm$get_call(), fixed = TRUE) ){
             if(position_hmatrix == 1){  
               position_z <- 2
             }else{ 
@@ -720,9 +722,9 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
               }else{ # two %X%
                 z1levels <- sort(unique(z1))
                 temp_d <- 1
-                for(j in 1:length(zlevels)){ # loop over z 
+                for(j in seq_along(zlevels)){ # loop over z
                   d[[ trm$get_names()[position_z] ]] <- zlevels[j] # use j-th factor level of z
-                  for(k in 1:length(z1levels)){ # loop over z1
+                  for(k in seq_along(z1levels)){ # loop over z
                     d[[ trm$get_names()[position_z1] ]] <- z1levels[k] # use k-th factor level of z1
                     attr(d, "add_main") <- paste0(trm$get_names()[position_z], "=", zlevels[j], ", ", 
                                                  trm$get_names()[position_z1], "=", z1levels[k])
@@ -825,7 +827,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
             }else{ ### functional response 
               
               ## not bhist 
-              if( ! grepl("bhist", trm$get_call()) ){
+              if( ! grepl("bhist", trm$get_call(), fixed = TRUE) ){
                 
                 ## y (time variable, usually second variable)
                 ## important in case of by-variables, then yind is third variable 
@@ -927,7 +929,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
         
         
         ## add dummy signal to data for bsignal()
-        if(grepl("bsignal", trm$get_call()) | grepl("bfpc", trm$get_call()) ){
+        if (grepl("bsignal|bfpc", trm$get_call())) {
           
           position_signal <- which(sapply(trm$model.frame(), 
                                           function(x) !is.null(attr(x, "signalIndex")) ))
@@ -942,7 +944,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
         ## as they cannot be included into the variable x(s)
         ## use intFun() to compute the integration weights
         # ls(environment(trm$dpp))
-        if(grepl("bhist", trm$get_call()) ){
+        if(grepl("bhist", trm$get_call(), fixed = TRUE) ){
           ## temp <- I(diag(ng)/integrationWeightsLeft(diag(ng), d[[varnms[1]]]))
           ## use intFun() of the bl to compute the integration weights
           temp <- environment(trm$dpp)$args$intFun(diag(ng), d[[attr(object$yind, "nameyind")]])
@@ -954,7 +956,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
         }
         
         ## add dummy signal to data for bconcurrent()
-        if(grepl("bconcurrent", trm$get_call())){
+        if(grepl("bconcurrent", trm$get_call(), fixed = TRUE)){
           d[[ trm$get_names()[1] ]] <- I(matrix(rep(1.0, ng^2), ncol=ng))
         }
         
@@ -973,20 +975,20 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
         
         
         # if %X% was used in combination with factor variables make a list of data-frames
-        if(!inherits(object, "FDboostLong") && grepl("%X", trm$get_call())){
+        if(!inherits(object, "FDboostLong") && grepl("%X", trm$get_call(), fixed = TRUE)){
           dlist <- NULL
 
           ## if %X% was used in combination with factor variables make a list of data-frames
-          if(is.factor(x) & is.factor(z)){ ## both variables are factors 
+          if(is.factor(x) && is.factor(z)){ ## both variables are factors 
             numberLevels <- nlevels(x) * nlevels(z)
             xlevels <- sort(unique(x))
             zlevels <- sort(unique(z))
             
             dlist <- vector("list", numberLevels)
             temp_d <- 1
-            for(j in 1:length(xlevels)){ # loop over x 
+            for(j in seq_along(xlevels)){ # loop over x
               d[[1]] <- xlevels[j] # use j-th factor level of x
-              for(k in 1:length(zlevels)){ # loop over z
+              for(k in seq_along(zlevels)){ # loop over z
                 d[[3]] <- zlevels[k] # use k-th factor level of z
                 attr(d, "xm") <- d[[1]]
                 attr(d, "zm") <- d[[3]]
@@ -1001,7 +1003,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
               numberLevels <- nlevels(z)
               zlevels <- sort(unique(z))
               dlist <- vector("list", numberLevels)
-              for(j in 1:length(zlevels)){ # loop over z 
+              for(j in seq_along(zlevels)){ # loop over z
                 d[[3]] <- rep(zlevels[j], length(d[[1]])) # use j-th factor level of z
                 attr(d, "zm") <- d[[3]]
                 attr(d, "add_main") <- paste0(names(d)[3], "=", zlevels[j])
@@ -1012,7 +1014,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
                 numberLevels <- nlevels(x)
                 xlevels <- sort(unique(x))
                 dlist <- vector("list", numberLevels)
-                for(j in 1:length(xlevels)){ # loop over x 
+                for(j in seq_along(xlevels)){ # loop over x
                   d[[1]] <- rep(xlevels[j], length(d[[3]])) # use j-th factor level of x
                   attr(d, "xm") <- d[[1]]
                   attr(d, "add_main") <- paste0(names(d)[1], "=", xlevels[j])
@@ -1024,7 +1026,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
                 numberLevels <- n4
                 zlevels <- seq(min(z), max(z), l = n4)
                 dlist <- vector("list", numberLevels)
-                for(j in 1:length(zlevels)){ # loop over x 
+                for(j in seq_along(zlevels)){ # loop over x
                   d[[3]] <- rep(zlevels[j], length(d[[1]])) # use j-th quantile of x
                   attr(d, "zm") <- d[[1]]
                   attr(d, "add_main") <- paste0(names(d)[3], "=", round(zlevels[j], 2))
@@ -1048,8 +1050,8 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
           if(!is.matrix(predHelp)){ 
             X <- predHelp
           }else{
-            X <- if(any(trm$get_names() %in% c("ONEtime")) | 
-                    any(class(object)=="FDboostScalar")){ # effect constant in t 
+            X <- if(any(trm$get_names() %in% "ONEtime") ||
+                    inherits(object, "FDboostScalar")){ # effect constant in t 
               predHelp[,1]
             }else{ 
               predHelp[1,] # smooth intercept/ concurrent effect                
@@ -1066,7 +1068,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
            
             ## for bhist(), multiply with standardisation weights if necessary
             ## you need the args$vecStand from the prediction of X, constructed here
-            if(grepl("bhist", trm$get_call())){
+            if(grepl("bhist", trm$get_call(), fixed = TRUE)){
               myargsHist <- myargs  ## use the args found in makeDataGrid() 
 
               ## this should only occur for more than two %X%
@@ -1108,13 +1110,13 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
                       z=attr(d, "zm"), zlab=varnms[3], vecStand=vecStand)
             
             ## include the second scalar covariate called z1 into the output
-            if( grepl("bhistx", trm$get_call()) & length(trm$get_names()) > 2){
+            if( grepl("bhistx", trm$get_call(), fixed = TRUE) && length(trm$get_names()) > 2){
               extra_output <- list(z1=attr(d, "z1m"), z1lab=varnms[4])
               P <- c(P, extra_output)
             }
             
             ## save the arguments of stand and limits as part of returned object
-            if(grepl("bhist", trm$get_call())){
+            if(grepl("bhist", trm$get_call(), fixed = TRUE)){
               P$stand <- myargsHist$stand
               P$limits <- myargsHist$limits
             }
@@ -1149,8 +1151,7 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
       
       trm <- object$baselearner[[i]]
       trm$dim <- length(trm$get_names())
-      if(any(grepl("ONEx", trm$get_names()), 
-             grepl("ONEtime", trm$get_names()))) trm$dim <- trm$dim - 1
+      if(any(grepl("ONE(x|time)", trm$get_names()))) trm$dim <- trm$dim - 1
       
       ### give error for bl1 %X% bl2 %X% bl3
       #if( grepl("bhistx", trm$get_call()) & trm$dim > 2){
@@ -1158,18 +1159,18 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
       #}
           
       ## add 1 to dimension of bhist and bhistx, otherwise dim is only 1  
-      if( grepl("bhist", trm$get_call()) ){
+      if( grepl("bhist", trm$get_call(), fixed = TRUE) ){
         trm$dim <- trm$dim + 1
       }
       
       # If a by-variable was specified, reduce number of dimensions
       # as smooth linear effect in several groups can be plotted in one plot 
-      if( grepl("by =", trm$get_call()) && grepl("bols", trm$get_call()) || 
-            grepl("by =", trm$get_call()) && grepl("bbs", trm$get_call()) ) trm$dim <- trm$dim - 1
+      if( grepl("by =", trm$get_call(), fixed = TRUE) && grepl("bols", trm$get_call(), fixed = TRUE) ||
+            grepl("by =", trm$get_call(), fixed = TRUE) && grepl("bbs", trm$get_call(), fixed = TRUE) ) trm$dim <- trm$dim - 1
       
       # <FIXME> what to do with bbs(..., by=factor)?
 
-      if(trm$dim > 3 & !grepl("bhistx", trm$get_call()) ){
+      if(trm$dim > 3 && !grepl("bhistx", trm$get_call(), fixed = TRUE) ){
         warning("Can't deal with smooths with more than 3 dimensions, returning NULL for ", 
                 shrtlbls[i], ".")
         return(NULL)
@@ -1178,28 +1179,27 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
       d <- makeDataGrid(trm)
       
       ### <FIXME> better solution for %X% in base-learner!!!
-      if(!is.null(object$ydim) && any(grepl("%X", trm$get_call())) 
-         && !any(grepl("bhistx", trm$get_call())) ) trm$dim <- trm$dim - 1
+      if(!is.null(object$ydim) && any(grepl("%X", trm$get_call(), fixed = TRUE)) 
+         && !any(grepl("bhistx", trm$get_call(), fixed = TRUE)) ) trm$dim <- trm$dim - 1
       
       ## it is necessary to expand the dataframe!
       if(!grepl("bhistx(", trm$get_call(), fixed=TRUE) && 
-         inherits(object, "FDboostLong") && !grepl("bconcurrent", trm$get_call())){
+         inherits(object, "FDboostLong") && !grepl("bconcurrent", trm$get_call(), fixed = TRUE)){
         #print(attr(d, "varnms"))
         vari <- names(d)[1]
         if(is.factor(d[[vari]])){
-          d[[vari]] <- d[[vari]][ rep(1:NROW(d[[vari]]), times=length(d[[attr(object$yind ,"nameyind")]]) ) ]
+          d[[vari]] <- d[[vari]][ rep(seq_len(NROW(d[[vari]])), times=length(d[[attr(object$yind ,"nameyind")]]) ) ]
           if(trm$dim>1) d[[attr(object$yind ,"nameyind")]] <- rep(d[[attr(object$yind ,"nameyind")]], 
                                                                   each=length(unique(d[[vari]]))  )
           }else{
           # expand signal variable
-          if( grepl("bhist(", trm$get_call(), fixed = TRUE) | 
-              grepl("bsignal", trm$get_call()) | grepl("bfpc", trm$get_call()) ){
+          if (grepl("bhist\\(|bsignal|bfpc", trm$get_call())) {
             vari <- names(d)[!names(d) %in% attr(d, "varnms")]
-            d[[vari]] <- d[[vari]][ rep(1:NROW(d[[vari]]), times=NROW(d[[vari]])), ]
+            d[[vari]] <- d[[vari]][ rep(seq_len(NROW(d[[vari]])), times=NROW(d[[vari]])), ]
             
           }else{ # expand scalar variable
             vari <- names(d)[1]
-            if(vari!=attr(object$yind ,"nameyind")) d[[vari]] <- d[[vari]][ rep(1:NROW(d[[vari]]), times=NROW(d[[vari]])) ]
+            if(vari!=attr(object$yind ,"nameyind")) d[[vari]] <- d[[vari]][ rep(seq_len(NROW(d[[vari]])), times=NROW(d[[vari]])) ]
           } 
           # expand yind 
           if(trm$dim>1) d[[attr(object$yind ,"nameyind")]] <- rep(d[[attr(object$yind ,"nameyind")]], 
@@ -1209,14 +1209,14 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
       
       ###### just return the data, that is used for the prediction
       if(returnData){
-        if(grepl("bhist", trm$get_call())){
+        if(grepl("bhist", trm$get_call(), fixed = TRUE)){
           message("If argument stand is specified !=\"no\", the standardization will be part of the predicted coefficient.")
         } 
         return(d)
       }
       
       if( !is.null(attr(d, "numberLevels")) && attr(d, "numberLevels") > 1){
-        if( grepl("bhistx", trm$get_call()) ) trm$dim <- 2
+        if( grepl("bhistx", trm$get_call(), fixed = TRUE) ) trm$dim <- 2
         ## get smooth coefficient estimates for several factor levels
         # P <- getP(d[[1]], trm = trm, myargs = attr(d, "myargsHist"))
         P <- lapply(d, getP, trm = trm, myargs = attr(d, "myargsHist")) 
@@ -1241,27 +1241,27 @@ coef.FDboost <- function(object, raw = FALSE, which = NULL,
       xpart <- unlist(strsplit(x, split = "%.{1,3}%"))
       ## find the expressions at which the split is done 
       operator <- gregexpr(pattern = "%.{1,3}%", text = x)[[1]]
-      operator <- sapply(1:length(operator), 
+      operator <- sapply(seq_along(operator),
                       function(i) substr(x, operator[i], operator[i] + attr(operator, "match.length")[i] -1 ) )
       
-      for(i in 1:length(xpart)){
+      for(i in seq_along(xpart)){
         xpart[i] <- gsub(pattern = "\\\"", replacement = "", x = xpart[i], fixed=TRUE)
         xpart[i] <- gsub(pattern = "\\", replacement = "", x = xpart[i], fixed=TRUE)
         nvar <- length(all.vars(formula(paste("Y~", xpart[i])))[-1])
-        commaSep <- unlist(strsplit(xpart[i], ","))  
+        commaSep <- unlist(strsplit(xpart[i], ",", fixed = TRUE))  
         
         # shorten the name to first variable and delete x= if present
-        if(grepl("=", commaSep[1])){
-          temp <- unlist(strsplit(commaSep[1], "="))
+        if(grepl("=", commaSep[1], fixed = TRUE)){
+          temp <- unlist(strsplit(commaSep[1], "=", fixed = TRUE))
           temp[1] <- unlist(strsplit(temp[1], "(", fixed=TRUE))[1]
           if(substr(temp[2], 1, 1)==" ") temp[2] <- substr(temp[2], 2, nchar(temp[2]))
           if(length(commaSep) == 1){ 
-            xpart[i] <- paste(temp[1], "(", temp[2], sep="")
+            xpart[i] <- paste0(temp[1], "(", temp[2])
           }else{
-            xpart[i] <- paste(temp[1], "(", temp[2], ")", sep="")
+            xpart[i] <- paste0(temp[1], "(", temp[2], ")")
           }
         }else{
-          if(length(commaSep) > 1){ xpart[i] <- paste(commaSep[1], ")", sep="")}
+          if(length(commaSep) > 1){ xpart[i] <- paste0(commaSep[1], ")")}
         }
         #xpart[i] <- if(length(commaSep)==1){
         #  paste(paste(commaSep[1:nvar], collapse=","), sep="")
@@ -1415,7 +1415,7 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
   
   ### get the effects to be plotted
   whichSpecified <- which 
-  if(is.null(which)) which <- 1:length(x$baselearner) 
+  if(is.null(which)) which <- seq_along(x$baselearner)
   
   if(onlySelected){
     which <- intersect(which, c(0, selected(x)))
@@ -1423,8 +1423,8 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
   
   # In the case that intercept and offset should be plotted and the intercept was never selected
   # plot the offset
-  if( (1 %in% whichSpecified | is.null(whichSpecified))  
-      & ! 1 %in% which & length(x$yind) > 1) which <- c(0, which)
+  if( (1 %in% whichSpecified || is.null(whichSpecified))  
+      && ! 1 %in% which && length(x$yind) > 1) which <- c(0, which)
   
   if(length(which) == 0){
     warning("Nothing selected for plotting.")
@@ -1457,14 +1457,14 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
     # plot the offset as extra effect
     # case 1: the offset should be included as extra plot
     # case 2: the whole model is plotted, but the intercept-base-learner was never selected
-    if( (! includeOffset | (includeOffset & ! 1 %in% which)) & 
-         is.null(whichSpecified) & ! is.null(selected(x))){
+    if( (! includeOffset || (includeOffset && ! 1 %in% which)) &&
+         is.null(whichSpecified) && ! is.null(selected(x))){
       terms <- c(offset = list(offsetTerms), terms)
       bl_data <- c(offset = list( list(x$yind) ), bl_data)
       names(bl_data[[1]]) <- attr(x$yind, "nameyind")     
     } 
    
-    if((length(terms) > 1 || is.null(terms[[1]]$dim) || terms[[1]]$dim == 3) & ask) par(ask = TRUE)
+    if((length(terms) > 1 || is.null(terms[[1]]$dim) || terms[[1]]$dim == 3) && ask) par(ask = TRUE)
     
     if(commonRange){
       range <- range(lapply(terms, function(x) x$value ))
@@ -1477,7 +1477,7 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
     ## trm <- terms[[i]] 
     myplot <- function(trm, range_i = NULL){
       
-      if(grepl("bhist", trm$main)){
+      if(grepl("bhist", trm$main, fixed = TRUE)){
         # set 0 to NA so that beta only has values in its domain
         # get the limits-function
         limits <- trm$limits
@@ -1504,16 +1504,16 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
                                    ylab="coef", type="l"))          
         }
         
-        if(rug & !is.factor(x = trm$x)){
-          if(grepl("bconcurrent", trm$main) | grepl("bsignal", trm$main) | grepl("bfpc", trm$main) ){
+        if(rug && !is.factor(x = trm$x)){
+          if (grepl("bconcurrent|bsignal|bfpc", trm$main)) {
             rug(attr(bl_data[[i]][[1]], "signalIndex"), ticksize = 0.02)
           }else rug(bl_data[[i]][[trm$xlab]], ticksize = 0.02)
         } 
       } 
       
       # plot with factor variable
-      if( (!grepl("bhistx", trm$main)) && trm$dim==2 &&
-          ((is.factor(trm$x) | is.factor(trm$y)) | is.factor(trm$z)) ){
+      if( (!grepl("bhistx", trm$main, fixed = TRUE)) && trm$dim==2 &&
+          ((is.factor(trm$x) || is.factor(trm$y)) || is.factor(trm$z)) ){
         
         ## plot for the special case where factor is plotted in several plots 
         if(!is.null(trm$add_main)){
@@ -1589,7 +1589,7 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
         
       }else{
         # persp-plot for 2-dim effects
-        if(trm$dim == 2 & pers){
+        if(trm$dim == 2 && pers){
           if(length(unique(as.vector(trm$value)))==1){
             # persp() gives error if only a flat plane should be drawn
             plot(y=trm$value[1,], x=trm$x, main=trm$main, type="l", xlab=trm$ylab, 
@@ -1608,7 +1608,7 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
           } 
         }
         # image for 2-dim effects
-        if(trm$dim == 2 & !pers){        
+        if(trm$dim == 2 && !pers){        
           plotWithArgs(image, args=argsImage,
                        myargs=list(x=trm$y, y=trm$x, z=t(trm$value), xlab=trm$ylab, ylab=trm$xlab, 
                                    main=trm$main, col = heat.colors(length(trm$x)^2)))          
@@ -1617,14 +1617,14 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
           
           if(rug){
             ##points(expand.grid(bl_data[[i]][[1]], bl_data[[i]][[2]]))
-            if(grepl("bhist", trm$main)){
+            if(grepl("bhist", trm$main, fixed = TRUE)){
               rug(x$yind, ticksize = 0.02)
             }else{
-              ifelse(grepl("by", trm$main) | ( !any(class(x)=="FDboostLong") && grepl("%X", trm$main) ) ,
+              ifelse(grepl("by", trm$main, fixed = TRUE) | ( !inherits(x, "FDboostLong") && grepl("%X", trm$main, fixed = TRUE) ) ,
                      rug(bl_data[[i]][[3]], ticksize = 0.02),
                      rug(bl_data[[i]][[2]], ticksize = 0.02))
             }
-            ifelse(grepl("bsignal", trm$main) | grepl("bfpc", trm$main) | grepl("bhist", trm$main),
+            ifelse(grepl("bsignal|bfpc|bhist", trm$main),
                    rug(attr(bl_data[[i]][[1]], "signalIndex"), ticksize = 0.02, side=2),
                    rug(bl_data[[i]][[1]], ticksize = 0.02, side=2))
           }
@@ -1632,24 +1632,24 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
       }
       ### 3 dim plots
       # persp-plot for 3-dim effects
-      if(trm$dim == 3 & pers){
-        for(j in 1:length(trm$z)){
+      if(trm$dim == 3 && pers){
+        for(j in seq_along(trm$z)){
           plotWithArgs(persp, args=argsPersp,
                        myargs=list(x=trm$x, y=trm$y, z=trm$value[[j]], xlab=paste("\n", trm$xlab), 
                                    ylab=paste("\n", trm$ylab), zlab=paste("\n", "coef"), 
                                    theta=30, phi=30, ticktype="detailed", 
                                    zlim=range(trm$value), col=getColPersp(trm$value[[j]]), 
-                                   main= paste(trm$zlab ,"=", round(trm$z[j],2), ": ", trm$main, sep=""))
+                                   main= paste0(trm$zlab ,"=", round(trm$z[j],2), ": ", trm$main))
           )         
         }
       }
       # image for 3-dim effects
-      if(trm$dim == 3 & !pers){
-        for(j in 1:length(trm$z)){
+      if(trm$dim == 3 && !pers){
+        for(j in seq_along(trm$z)){
           plotWithArgs(image, args=argsImage,
                        myargs=list(x=trm$x, y=trm$y, z=trm$value[[j]], xlab=trm$xlab, ylab=trm$ylab,
                                    col = heat.colors(length(trm$x)^2), zlim=range(trm$value),
-                                   main= paste(trm$zlab ,"=", round(trm$z[j],2), ": ", trm$main, sep="")))
+                                   main= paste0(trm$zlab ,"=", round(trm$z[j],2), ": ", trm$main)))
           plotWithArgs(contour, args=argsContour,
                        myargs=list(trm$x, trm$y, trm$value[[j]], xlab=trm$xlab, add = TRUE))
           if(rug){
@@ -1660,7 +1660,7 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
       
     }  ## end function myplot()
     
-    for(i in 1:length(terms)){
+    for(i in seq_along(terms)){
       
       trm <- terms[[i]] 
       
@@ -1676,7 +1676,7 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
       
     } # end for-loop
     
-    if(length(terms)>1 & ask) par(ask = FALSE) 
+    if(length(terms)>1 && ask) par(ask = FALSE) 
     
   ### plot smooth effects as they are estimated for the original data
   }else{
@@ -1687,9 +1687,9 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
     offset <- attr(terms, "offset")
     
     # convert matrix into a list, each list entry for one effect
-    if(is.null(x$ydim) & !is.null(dim(terms))){
+    if(is.null(x$ydim) && !is.null(dim(terms))){
       temp <- list()
-      for(i in 1:ncol(terms)){
+      for(i in seq_len(ncol(terms))){
         temp[[i]] <- terms[,i]
       }
       names(temp) <- colnames(terms)
@@ -1712,11 +1712,11 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
     time <- x$yind
     
     # include the offset in the plot of the intercept
-    if( includeOffset && 1 %in% which && grepl("ONEx", shrtlbls[1]) ){
+    if( includeOffset && 1 %in% which && grepl("ONEx", shrtlbls[1], fixed = TRUE) ){
       terms[[1]] <- terms[[1]] + x$offset
       shrtlbls[1] <- paste("offset", "+", shrtlbls[1])
     }   
-    if(length(which) > 1 & ask) par(ask = TRUE)
+    if(length(which) > 1 && ask) par(ask = TRUE)
 
     if(commonRange){
       range <- range(terms)
@@ -1726,7 +1726,7 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
     
     if(!is.null(dots$ylim)) range <- dots$ylim
     
-    for(i in 1:length(terms)){
+    for(i in seq_along(terms)){
       
       # set values of predicted effect to missing if response is missing
       if(sum(is.na(x$response)) > 0) terms[[i]][is.na(x$response)] <- NA
@@ -1758,7 +1758,7 @@ plot.FDboost <- function(x, raw = FALSE, rug = TRUE, which = NULL,
       }
     }
     
-    if(length(which) > 1 & ask) par(ask = FALSE) 
+    if(length(which) > 1 && ask) par(ask = FALSE) 
   }
   
 }
@@ -1807,7 +1807,7 @@ update.FDboost <- function(object, weights = NULL, oobweights = NULL, risk = NUL
   
   extras <- match.call(expand.dots = FALSE)$...
   
-  if (!is.null(risk) | !is.null(trace) | !is.null(extras$control)) {
+  if (!is.null(risk) || !is.null(trace) || !is.null(extras$control)) {
     
     cc <- as.list(call$control)
     if(length(cc)==0) cc <- list(as.symbol("boost_control"))
@@ -1878,16 +1878,16 @@ update.FDboost <- function(object, weights = NULL, oobweights = NULL, risk = NUL
       
       ### check for brackets
       singleBls <- gsub("\\s", "", unlist(lapply(strsplit(
-        strsplit(object$formulaFDboost, "~")[[1]][2], # split formula
-        "\\+")[[1]], # split additive terms
+        strsplit(object$formulaFDboost, "~", fixed = TRUE)[[1]][2], # split formula
+        "+", fixed = TRUE)[[1]], # split additive terms
         function(y) strsplit(y, split = "%.{1,3}%")) # split single baselearners
       )) 
       
       singleBls <- singleBls[singleBls!="1"]
       
-      if(any( !grepl("\\(",singleBls) )) 
+      if(any( !grepl("(",singleBls, fixed = TRUE) )) 
         stop(paste0("update can not deal with the following base-learner(s) without brackets: ", 
-                    paste(singleBls[!grepl("\\(",singleBls)], collapse=", "), ".\n",
+                    toString(singleBls[!grepl("(", singleBls, fixed = TRUE)]), ".\n",
                     "Please build such base-learners within the FDboost call or ",  
                     "update corresponding baselearner(s) manually and supply a new formula to the update function."))
       
@@ -1929,7 +1929,7 @@ extract.blg <- function(object, what = c("design", "penalty", "index"),
                         asmatrix = FALSE, expand = FALSE, ...){
   what <- match.arg(what)
   
-  if(grepl("%O%", object$get_call()) | grepl("%Oz%", object$get_call())){
+  if (grepl("%O%|%Oz%", object$get_call())) {
     object <- object$dpp( rep(1, NROW(object$model.frame()[[1]])) )    
   }else{
     object <- object$dpp(rep(1, nrow(object$model.frame())))
