@@ -12,7 +12,7 @@
 #' @export 
 o_control <- function(k_min=20, rule=2, silent=TRUE, cyclic=FALSE, knots=NULL) { 
   RET <- list(k_min=k_min, rule=rule, silent=silent, cyclic=cyclic, knots=knots)
-  class(RET) <- c("offset_control")
+  class(RET) <- "offset_control"
   RET
 }
 
@@ -54,7 +54,7 @@ truncateTime <- function(funVar, time, newtime, data){
   ret <- data
   ret[[time]] <- newtime
   
-  for(i in 1:length(funVar)){
+  for(i in seq_along(funVar)){
     ret[[funVar[i]]] <- ret[[funVar[i]]][ , data[[time]] %in% newtime] 
   }  
   rm(data)
@@ -153,7 +153,7 @@ funplot <- function(x, y, id=NULL, rug=TRUE, ...){
     stopifnot(length(x)==length(y) & length(y)==length(id))
     
     idOrig <- id
-    for(i in 1:length(unique(idOrig))){
+    for(i in seq_along(unique(idOrig))){
       id[idOrig==unique(idOrig)[i]] <- i
     }
     
@@ -224,18 +224,18 @@ funplot <- function(x, y, id=NULL, rug=TRUE, ...){
 ### function to plot the observed response and the predicted values of a model
 plotPredicted <- function(x, subset=NULL, posLegend="topleft", lwdObs=1, lwdPred=1, ...){
   
-  stopifnot("FDboost" %in% class(x))
+  stopifnot(inherits(x, "FDboost"))
   
-  if(any(class(x) == "FDboostScalar")){
+  if(inherits(x, "FDboostScalar")){
     
-    if(is.null(subset)) subset <- 1:length(x$response)
+    if(is.null(subset)) subset <- seq_along(x$response)
     response <- x$response[subset, drop=FALSE] 
     pred <- fitted(x)[subset, drop=FALSE]
     pred[is.na(response)] <- NA
     
   }else{
     
-    if(!any(class(x) == "FDboostLong")){
+    if(!inherits(x, "FDboostLong")){
       if(is.null(subset)) subset <- 1:x$ydim[1]
       response <- matrix(x$response, nrow=x$ydim[1], ncol=x$ydim[2])[subset, , drop=FALSE] 
       pred <- fitted(x)[subset, , drop=FALSE]
@@ -253,7 +253,7 @@ plotPredicted <- function(x, subset=NULL, posLegend="topleft", lwdObs=1, lwdPred
     
   }
   
-  if(is.character(response) | is.factor(x$response)){
+  if(is.character(response) || is.factor(x$response)){
 
     if(length(x$yind) > 1){
       message("For functional response that is not continuous only the predicted values are plotted.")
@@ -292,17 +292,17 @@ plotPredicted <- function(x, subset=NULL, posLegend="topleft", lwdObs=1, lwdPred
 ### function to plot the residuals
 plotResiduals <- function(x, subset=NULL, posLegend="topleft", ...){
   
-  stopifnot("FDboost" %in% class(x))
+  stopifnot(inherits(x, "FDboost"))
   
-  if(any(class(x) == "FDboostScalar")){
+  if(inherits(x, "FDboostScalar")){
     
-    if(is.null(subset)) subset <- 1:length(x$response)
+    if(is.null(subset)) subset <- seq_along(x$response)
     response <- x$response[subset, drop=FALSE] 
     resid <- x$resid()[subset, drop=FALSE]
     
   }else{
     
-    if(!any(class(x) == "FDboostLong")){ ## wide format
+    if(!inherits(x, "FDboostLong")){ ## wide format
       if(is.null(subset)) subset <- 1:x$ydim[1]
       resid <- matrix(x$resid(), nrow = x$ydim[1])[subset, , drop=FALSE]
       yind <- x$yind
@@ -349,9 +349,9 @@ getYYhatTime <- function(object, breaks=object$yind){
     yInter <- t(apply(y, 1, function(x) approx(object$yind, x, xout=time)$y))
     # Get dataframe to predict values at time
     newdata <- list()
-    for(j in 1:length(object$baselearner)){
+    for(j in seq_along(object$baselearner)){
       datVarj <- object$baselearner[[j]]$get_data()
-      if(grepl("bconcurrent", names(object$baselearner)[j])){
+      if(grepl("bconcurrent", names(object$baselearner)[j], fixed = TRUE)){
         datVarj <- t(apply(datVarj[[1]], 1, function(x) approx(object$yind, x, xout=time)$y))
         datVarj <- list(datVarj)
       } 
@@ -410,13 +410,13 @@ getYYhatTime <- function(object, breaks=object$yind){
 #' @export
 funRsquared <- function(object, overTime=TRUE, breaks=object$yind, global=FALSE, ...){
   
-  if(length(object$yind)<2 | any(class(object)=="FDboostLong")){
+  if(length(object$yind)<2 || inherits(object, "FDboostLong")){
     y <- object$response
     yhat <- object$fitted()
     time <- object$yind
     id <- object$id
-    if(is.null(id)) id <- 1:length(y)
-    if(overTime & !global) {
+    if(is.null(id)) id <- seq_along(y)
+    if(overTime && !global) {
       overTime <- FALSE
       message("For scalar or irregualr response the functional R-squared cannot be computed over time.")
     }
@@ -457,7 +457,7 @@ funRsquared <- function(object, overTime=TRUE, breaks=object$yind, global=FALSE,
     attr(ret, "missings") <- apply(y, 2, function(x) sum(is.na(x))/length(x) )
     
   }else{ ### for each subject i
-    if(length(object$yind)<2 | any(class(object)=="FDboostLong")){
+    if(length(object$yind)<2 || inherits(object, "FDboostLong")){
       # Mean for each subject
       mut <- tapply(y, id, mean, na.rm=TRUE  )[id]
       # numerator cannot be 0
@@ -527,13 +527,13 @@ funRsquared <- function(object, overTime=TRUE, breaks=object$yind, global=FALSE,
 funMSE <- function(object, overTime=TRUE, breaks=object$yind, global=FALSE, 
                    relative=FALSE, root=FALSE, ...){
   
-  if(length(object$yind)<2 | any(class(object)=="FDboostLong")){
+  if(length(object$yind)<2 || inherits(object, "FDboostLong")){
     y <- object$response
     yhat <- object$fitted()
     time <- object$yind
     id <- object$id
-    if(is.null(id)) id <- 1:length(y)
-    if(overTime & !global) {
+    if(is.null(id)) id <- seq_along(y)
+    if(overTime && !global) {
       overTime <- FALSE
       message("For scalar or irregualr response the functional MSE cannot be computed over time.")
     }
@@ -557,7 +557,7 @@ funMSE <- function(object, overTime=TRUE, breaks=object$yind, global=FALSE,
       attr(ret, "missings") <- apply(y, 2, function(x) sum(is.na(x))/length(x))     
     }else{ 
       ### for each subject i
-      if(length(object$yind)<2 | any(class(object)=="FDboostLong")){
+      if(length(object$yind)<2 || inherits(object, "FDboostLong")){
         ret <- tapply((y - yhat)^2, id, mean, na.rm=TRUE  )
         attr(ret, "name") <- "MSE over subjects"              
       }else{
@@ -614,13 +614,13 @@ funMSE <- function(object, overTime=TRUE, breaks=object$yind, global=FALSE,
 #' @export
 funMRD <- function(object, overTime=TRUE, breaks=object$yind, global=FALSE,  ...){
   
-  if(length(object$yind)<2 | any(class(object)=="FDboostLong")){
+  if(length(object$yind)<2 || inherits(object, "FDboostLong")){
     y <- object$response
     yhat <- object$fitted()
     time <- object$yind
     id <- object$id
-    if(is.null(id)) id <- 1:length(y)
-    if(overTime & !global) {
+    if(is.null(id)) id <- seq_along(y)
+    if(overTime && !global) {
       overTime <- FALSE
       message("For scalar or irregualr response the functional MRD cannot be computed over time.")
     }
@@ -648,7 +648,7 @@ funMRD <- function(object, overTime=TRUE, breaks=object$yind, global=FALSE,  ...
       attr(ret, "missings") <- apply(y, 2, function(x) sum(is.na(x))/length(x))     
     }else{ 
       ### for each subject i
-      if(length(object$yind)<2 | any(class(object)=="FDboostLong")){
+      if(length(object$yind)<2 || inherits(object, "FDboostLong")){
         ret <- tapply( abs((y1 - yhat) / y1), id, mean, na.rm=TRUE  )
         attr(ret, "name") <- "MRD over subjects"              
       }else{
@@ -717,7 +717,7 @@ check_ident <- function(X1, L, Bs, K, xname, penalty,
   ## logCondDs <- log10(e_DstDs$values[1]) - log10(tail(e_DstDs$values, 1))
   evDs <- svd(Ds, nu = 0, nv = 0)$d^2  ## the same as eigenvalues of DstDs
   logCondDs <- log10(max(evDs)) - log10(min(evDs))
-  if(giveWarnings & logCondDs > 6 & is.null(limits)){
+  if(giveWarnings && logCondDs > 6 && is.null(limits)){
     warning("Condition number for <", xname, "> greater than 10^6 (logCondDs = ", round(logCondDs, 2),"). ", 
             "Effect identifiable only through penalty.")
   }
@@ -731,10 +731,10 @@ check_ident <- function(X1, L, Bs, K, xname, penalty,
     ind0Bs <- ((!ind0)*1) %*% Bs # matrix to check for 0 columns
     ## implementation is suitable for common grid of t, maybe with some missings
     ## common grid is assumed if Y(t) is observed at least in 80% for each point 
-    if( length(yind) < nrow(X1des) | all(table(yind) / max(id) > 0.8) ){
+    if( length(yind) < nrow(X1des) || all(table(yind) / max(id) > 0.8) ){
       if(is.null(t_unique)) t_unique <- sort(unique(yind))
       logCondDs_hist <- rep(NA, length=length(t_unique))
-      for(k in 1:length(t_unique)){
+      for(k in seq_along(t_unique)){
         Ds_t <- X1des[yind==t_unique[k], ] # get rows of Ds corresponding to yind
         ind0Bs_t <- ind0Bs[yind==t_unique[k], ] # get rows of ind0Bs corresponding to yind
         # only keep columns that are not completely 0, otherwise matrix is always rank deficient
@@ -752,7 +752,7 @@ check_ident <- function(X1, L, Bs, K, xname, penalty,
           logCondDs_hist[k] <- log10(max(evDs)) - log10(min(evDs))
         }
         ## matplot(xind, Bs, type="l", lwd=2, ylim=c(-2,2)); rug(xind); rug(yind, col=2, lwd=2)
-        ## matplot(knots[1:ncol(Ds_t)], t(Ds_t), type="l", lwd=1, add=TRUE)
+        ## matplot(knots[seq_len(ncol(Ds_t))], t(Ds_t), type="l", lwd=1, add=TRUE)
         ## lines(t_unique, logCondDs_hist-6, col=2, lwd=4)
       }
       names(logCondDs_hist) <- round(t_unique,2)
@@ -792,7 +792,7 @@ check_ident <- function(X1, L, Bs, K, xname, penalty,
       }
       names(logCondDs_hist) <- round(t_unique[-length(t_unique)],2)
     }
-    if(giveWarnings & any(logCondDs_hist > 6)){
+    if(giveWarnings && any(logCondDs_hist > 6)){
       # get the first and the last entry of t, for which the condition number is >10^6
       tempL <- names(which.min(which(logCondDs_hist > 6)))
       tempU <- names(which.max(which(logCondDs_hist > 6)))
@@ -829,20 +829,20 @@ check_ident <- function(X1, L, Bs, K, xname, penalty,
   if(!is.null(limits)){  
     
     subs <- list()
-    for(k in 1:length(t_unique)){
+    for(k in seq_along(t_unique)){
       subs[[k]] <- which(limits(s=xind, t=t_unique[k]))
     }
     cumOverlapKe <- sapply(subs, getOverlap, X1=X1, L=L, Bs=Bs, K=K)
     overlapKe <- max(cumOverlapKe, na.rm = TRUE) #cumOverlapKe[[length(cumOverlapKe)]]
     
   }else{ # overlap between whole matrix X and penalty
-    overlapKe <- getOverlap(subset=1:ncol(X1), X1=X1, L=L, Bs=Bs, K=K)
+    overlapKe <- getOverlap(subset=seq_len(ncol(X1)), X1=X1, L=L, Bs=Bs, K=K)
   }
   
   # look at overlap with whole functional covariate 
-  overlapKeComplete  <- getOverlap(subset=1:ncol(X1), X1=X1, L=L, Bs=Bs, K=K)
+  overlapKeComplete  <- getOverlap(subset=seq_len(ncol(X1)), X1=X1, L=L, Bs=Bs, K=K)
   
-  if(giveWarnings & overlapKe >= 1){
+  if(giveWarnings && overlapKe >= 1){
     warning("Kernel overlap for <", xname, "> and the specified basis and penalty detected. ",
             "Changing basis for x-direction to <penalty='pss'> to make model identifiable through penalty. ", 
             "Coefficient surface estimate will be inherently unreliable. ", 
@@ -865,11 +865,11 @@ trace_lv <- function(A, B, tol=1e-10){
   # Rolf Larsson, Mattias Villani (2001)
   # "A distance measure between cointegration spaces"
   
-  if(NCOL(A)==0 | NCOL(B)==0){
+  if(NCOL(A)==0 || NCOL(B)==0){
     return(0)
   }
   
-  if(NROW(A) != NROW(B) | NCOL(A) > NROW(A) | NCOL(B) > NROW(B)){
+  if(NROW(A) != NROW(B) || NCOL(A) > NROW(A) || NCOL(B) > NROW(B)){
     return(NA)
   }
   
@@ -1018,9 +1018,9 @@ reweightData <- function(data, argvals, vars,
                          idvars = NULL, compress = FALSE)
 {
   
-  if(missing(argvals) & missing(vars)) 
+  if(missing(argvals) && missing(vars)) 
     stop("Either argvals or vars must be supplied.")
-  if(missing(weights) & missing(index)) 
+  if(missing(weights) && missing(index)) 
     stop("Either weights or index must be supplied.")
 
   # get names of data
@@ -1029,7 +1029,7 @@ reweightData <- function(data, argvals, vars,
   # if(missing(idvars)) idvars <- NULL
   
   # drop not used entries if both argvals and vars are given
-  if(!missing(argvals) & !missing(vars)){
+  if(!missing(argvals) && !missing(vars)){
     
     data[nd[!nd %in% c(argvals, vars, longvars, idvars)]] <- NULL
     nd <- names(data) # reset names
@@ -1045,11 +1045,11 @@ reweightData <- function(data, argvals, vars,
   # check names
   if(length(whichNot) != 0) 
     stop(paste0("Could not find ", 
-                paste(c(argvals, vars, idvars, longvars)[whichNot], collapse = ", "),
+                toString(c(argvals, vars, idvars, longvars)[whichNot]),
                 " in data."))
   
   # check for hmatrix and delete in argvals or vars if present
-  whichHmat <- sapply(data[vars], function(x) "hmatrix" %in% class(x))
+  whichHmat <- sapply(data[vars], is.hmatrix)
   
   # get dimensions of data
   dimd <- lapply(data, dim)
@@ -1107,7 +1107,7 @@ reweightData <- function(data, argvals, vars,
   
   ## check that all idvars are equal
   if(length(idvars)>1)
-    if(!all(sapply(data[idvars][-1],function(x)all.equal(data[idvars][[1]],x)=="TRUE")))
+    if(!all(sapply(data[idvars][-1],function(x) isTRUE(all.equal(data[idvars][[1]], x)))))
       stop("All idvars must be identical.")
   idvars_new <- NULL
   
@@ -1128,16 +1128,16 @@ reweightData <- function(data, argvals, vars,
     newHmats <- vector("list", length(nhm))
     
     ## construct the new hmatrices
-    for(j in 1:length(nhm)){
+    for(j in seq_along(nhm)){
       
       ## check that idvars == idvars[[1]] and match id-variables in all hmatrix-objects
-      if(!is.null(idvars) && !(all.equal(c(getId(data[[nhm[j]]])), c(data[[idvars[1]]])) == "TRUE")) 
+      if(!is.null(idvars) && !isTRUE(all.equal(c(getId(data[[nhm[j]]])), c(data[[idvars[1]]]))))
         stop("id variable in hmatrix object must be equal to idvars")
       
       ## subset hmatrix
       newHmats[[j]] <- subset_hmatrix(data[[nhm[j]]], index = index, compress = compress)
       
-      if( any(class(data[[nhm[j]]]) == "AsIs") ){
+      if( inherits(data[[nhm[j]]], "AsIs") ){
         newHmats[[j]] <- I(newHmats[[j]])
       }
       
@@ -1157,7 +1157,7 @@ reweightData <- function(data, argvals, vars,
     if(any(idvars %in% longvars)) longvars <- longvars[!longvars %in% idvars]
     ## create weights and index in long format
     weights_long <- weights[data[[idvars[1]]]]
-    index_long <- rep(1:length(weights_long), weights_long)
+    index_long <- rep(seq_along(weights_long), weights_long)
     ## indexing variables in long format
     temp_long <- lapply(longvars, function(nameWithoutDim) data[[nameWithoutDim]][index_long])
     
@@ -1178,7 +1178,7 @@ reweightData <- function(data, argvals, vars,
     my_temp_idvars <- temp_idvars
     i <- 1
     ## add 0.1^1 to duplicates, 0.1^1 + 0.1^2 = 0.11 to triplicates, ...
-    while(any(duplicated(my_index_long))){ # loop until no more duplicates in the data  
+    while(anyDuplicated(my_index_long) > 0){ # loop until no more duplicates in the data
       my_temp_idvars[duplicated(my_index_long)] <- my_temp_idvars[duplicated(my_index_long)] + 0.1^i
       my_index_long[duplicated(my_index_long)] <- my_index_long[duplicated(my_index_long)] + 0.1^i
       i <- i + 1
@@ -1200,7 +1200,7 @@ reweightData <- function(data, argvals, vars,
   if(!is.null(idvars)){
     
     ## only works for common observation grid of response
-    ## idvars_new <- rep(1:length(index), nc) # index = c(1, 1, 2) -> 1, 2, 3
+    ## idvars_new <- rep(seq_along(index), nc) # index = c(1, 1, 2) -> 1, 2, 3
     
     for(ifr in idvars){
       data[[ifr]] <- idvars_new
